@@ -40,7 +40,7 @@
 
 struct {
 	int	flags;
-	char	*str;
+	const	char	*str;
 } upscli_errlist[] =
 {
 	{ 0, "Unknown error"			},	/*  0: UPSCLI_ERR_UNKNOWN */
@@ -201,6 +201,14 @@ static int net_read(UPSCONN *ups, char *buf, size_t buflen)
 
 	ret = read(ups->fd, buf, buflen);
 
+	if (ret == 0) {
+		ups->upserror = UPSCLI_ERR_SRVDISC;
+		ups->syserrno = 0;
+		upscli_closefd(ups);
+
+		return -1;
+	}		
+
 	if (ret < 1) {
 		ups->upserror = UPSCLI_ERR_READ;
 		ups->syserrno = errno;
@@ -243,7 +251,8 @@ static int net_write(UPSCONN *ups, const char *buf, size_t count)
 /* internal: bring back a line (up to LF or buflen bytes) */
 static int upscli_read(UPSCONN *ups, char *buf, size_t buflen)
 {
-	int	ret, numrec = 0;
+	int	ret;
+	size_t	numrec = 0;
 	char	ch;
 
 	if (!ups)
@@ -280,7 +289,7 @@ static int upscli_read(UPSCONN *ups, char *buf, size_t buflen)
 	
 /* stub first */
 #ifndef HAVE_SSL
-int upscli_sslinit(UPSCONN *ups)
+static int upscli_sslinit(UPSCONN *ups)
 {
 	return 0;		/* not supported */
 }
@@ -301,7 +310,7 @@ int upscli_sslcert(UPSCONN *ups, const char *dir, const char *file, int verify)
 
 #else
 
-int upscli_sslinit(UPSCONN *ups)
+static int upscli_sslinit(UPSCONN *ups)
 {
 	int	ret;
 	char	buf[UPSCLI_NETBUF_LEN];
@@ -517,7 +526,7 @@ int upscli_connect(UPSCONN *ups, const char *host, int port, int flags)
 /* map upsd error strings back to upsclient internal numbers */
 static struct {
 	int	errnum;
-	char	*text;
+	const	char	*text;
 }	upsd_errlist[] =
 {
 	{ UPSCLI_ERR_VARNOTSUPP,	"VAR-NOT-SUPPORTED"	},	
@@ -584,7 +593,8 @@ static void build_cmd(char *buf, size_t bufsize, const char *cmdname,
 {
 	int	i;
 	size_t	len;
-	char	enc[UPSCLI_NETBUF_LEN], *format;
+	char	enc[UPSCLI_NETBUF_LEN];
+	const char	*format;
 
 	memset(buf, '\0', bufsize);
 	snprintf(buf, bufsize, "%s", cmdname);
@@ -624,8 +634,8 @@ static int verify_resp(int num, const char **q, char **a)
 	return 1;	/* OK */
 }
 
-int upscli_get(UPSCONN *ups, int numq, const char **query, 
-		int *numa, char ***answer)
+int upscli_get(UPSCONN *ups, unsigned int numq, const char **query, 
+		unsigned int *numa, char ***answer)
 {
 	int	ret;
 	char	cmd[UPSCLI_NETBUF_LEN], tmp[UPSCLI_NETBUF_LEN];
@@ -673,7 +683,7 @@ int upscli_get(UPSCONN *ups, int numq, const char **query,
 	return 0;
 }
 
-int upscli_list_start(UPSCONN *ups, int numq, const char **query)
+int upscli_list_start(UPSCONN *ups, unsigned int numq, const char **query)
 {
 	int	ret;
 	char	cmd[UPSCLI_NETBUF_LEN], tmp[UPSCLI_NETBUF_LEN];
@@ -727,8 +737,8 @@ int upscli_list_start(UPSCONN *ups, int numq, const char **query)
 	return 0;
 }
 
-int upscli_list_next(UPSCONN *ups, int numq, const char **query, 
-		int *numa, char ***answer)
+int upscli_list_next(UPSCONN *ups, unsigned int numq, const char **query, 
+		unsigned int *numa, char ***answer)
 {
 	char	tmp[UPSCLI_NETBUF_LEN];
 
@@ -770,169 +780,6 @@ int upscli_list_next(UPSCONN *ups, int numq, const char **query,
 	return 1;
 }
 
-/* --- */
-
-int upscli_getvar(UPSCONN *ups, const char *upsname, const char *var, 
-			char *buf, size_t buflen)
-{
-	int	ret, skiplen;
-	char	cmd[UPSCLI_NETBUF_LEN], tmp[UPSCLI_NETBUF_LEN], *ptr;
-
-	if (!ups)
-		return -1;
-
-	if ((!buf) || (!var) || (buflen < 1) || (ups->fd == -1)) {
-		ups->upserror = UPSCLI_ERR_INVALIDARG;
-		return -1;
-	}
-
-	if (!upscli_checkmagic(ups)) {
-		ups->upserror = UPSCLI_ERR_INVALIDARG;
-		return -1;
-	}
-
-	if (upsname)
-		snprintf(cmd, sizeof(cmd), "REQ %s@%s\n", var, upsname);
-	else
-		snprintf(cmd, sizeof(cmd), "REQ %s\n", var);
-
-	ret = net_write(ups, cmd, strlen(cmd));
-
-	if (ret < 0)
-		return -1;
-
-	if (upscli_read(ups, tmp, sizeof(tmp)) != 0)
-		return -1;
-
-	if (upscli_errcheck(ups, tmp) != 0)
-		return -1;
-
-	if (strncmp(tmp, "ANS", 3) != 0) {
-		ups->upserror = UPSCLI_ERR_INVRESP;
-
-		/* try to copy some of it for later inspection */
-		snprintf(buf, buflen, "%s", tmp);
-
-		return -1;
-	}
-
-	if (!upsname) {
-
-		/* skip "ANS <var> " */
-		skiplen = 4 + strlen(var) + 1;
-
-	} else {
-
-		/* skip "ANS <var>@<upsname> " */
-		skiplen = 4 + strlen(var) + 1 + strlen(upsname) + 1;
-	}
-
-	/* make sure we got enough data */
-	if (strlen(tmp) <= skiplen) {
-		ups->upserror = UPSCLI_ERR_INVRESP;
-
-		/* try to copy some of it for later inspection */
-		snprintf(buf, buflen, "%s", tmp);
-
-		return -1;
-	}
-
-	ptr = tmp + skiplen;
-	snprintf(buf, buflen, "%s", ptr);
-
-	return 0;
-}
-
-static struct {
-	int	type;
-	char	*cmd;
-	char	*resp;
-}	upscli_cmdlist[] =
-{
-	{ UPSCLI_LIST_VARS, 	"LISTVARS",	"VARS",		},
-	{ UPSCLI_LIST_RW,	"LISTRW",	"RW",		},
-	{ UPSCLI_LIST_CMDS,	"LISTINSTCMD",	"INSTCMDS",	},
-	{ 0,			NULL,		NULL		}
-};
-
-int upscli_getlist(UPSCONN *ups, const char *upsname, int listtype, 
-			char *buf, size_t buflen)
-{
-	int	ret, i, cmdpos;
-	char	cmd[UPSCLI_NETBUF_LEN], tmp[UPSCLI_NETBUF_LEN], *ptr;
-
-	if (!ups)
-		return -1;
-
-	if ((!buf) || (buflen < 1) || (ups->fd == -1)) {
-		ups->upserror = UPSCLI_ERR_INVALIDARG;
-		return -1;
-	}
-
-	if (!upscli_checkmagic(ups)) {
-		ups->upserror = UPSCLI_ERR_INVALIDARG;
-		return -1;
-	}
-
-	cmdpos = -1;
-
-	for (i = 0; upscli_cmdlist[i].cmd != NULL; i++) {
-		if (upscli_cmdlist[i].type == listtype) {
-			cmdpos = i;
-			break;
-		}
-	}
-
-	if (cmdpos == -1) {
-		ups->upserror = UPSCLI_ERR_INVLISTTYPE;
-		return -1;
-	}
-
-	if (upsname)
-		snprintf(cmd, sizeof(cmd), "%s %s\n", 
-			upscli_cmdlist[cmdpos].cmd, upsname);
-	else
-		snprintf(cmd, sizeof(cmd), "%s\n",
-			upscli_cmdlist[cmdpos].cmd);
-
-	ret = net_write(ups, cmd, strlen(cmd));
-
-	if (ret < 0) 
-		return -1;
-
-	if (upscli_read(ups, tmp, sizeof(tmp)) != 0)
-		return -1;
-
-	if (upscli_errcheck(ups, tmp) != 0)
-		return -1;
-
-	if (strncmp(tmp, upscli_cmdlist[cmdpos].resp,
-		strlen(upscli_cmdlist[cmdpos].resp)) != 0) {
-		ups->upserror = UPSCLI_ERR_INVRESP;
-
-		/* try to copy some of it for later inspection */
-		snprintf(buf, buflen, "%s", tmp);
-
-		return -1;
-	}
-
-	if (!upsname) {
-
-		/* skip "<resp> " */
-		ptr = tmp + strlen(upscli_cmdlist[cmdpos].resp) + 1;
-
-	} else {
-
-		/* skip "<resp> @<name> " */
-		ptr = tmp + strlen(upscli_cmdlist[cmdpos].resp) +
-			strlen(upsname) + 3;	
-	}
-
-	snprintf(buf, buflen, "%s", ptr);
-
-	return 0;
-}
-
 int upscli_sendline(UPSCONN *ups, const char *buf, size_t buflen)
 {
 	int	ret;
@@ -986,8 +833,6 @@ int upscli_readline(UPSCONN *ups, char *buf, size_t buflen)
 	return 0;
 }
 
-/* FUTURE: this will not allow a missing upsname component */
-
 /* split [upsname@]hostname[:port] into separate components */
 int upscli_splitname(const char *buf, char **upsname, char **hostname,
 			int *port)
@@ -1001,23 +846,21 @@ int upscli_splitname(const char *buf, char **upsname, char **hostname,
 
 	ap = strchr(tmp, '@');
 
-	if (ap) {
-		*ap++ = '\0';
-		*upsname = strdup(tmp);
-
-		if (!*upsname) {
-			fprintf(stderr, "upscli_splitname: strdup failed\n");
-			return -1;
-		}
-
-		ptr = ap;
-
-	} else {
-
-		*upsname = NULL;
-		ptr = tmp;
+	if (!ap) {
+		fprintf(stderr, "upscli_splitname: no UPS name specified (upsname@hostname)\n");
+		return -1;
 	}
 
+	*ap++ = '\0';
+	*upsname = strdup(tmp);
+
+	if (!*upsname) {
+		fprintf(stderr, "upscli_splitname: strdup failed\n");
+		return -1;
+	}
+
+	ptr = ap;
+
 	cp = strchr(ptr, ':');
 
 	if (cp) {
