@@ -15,7 +15,7 @@ static void do_var(const char *arg);
 static void do_etime(const char *arg);
 
 struct {
-	char	*name;
+	const	char	*name;
 	void	(*func)(const char *arg);
 }	logcmds[] =
 {
