@@ -19,6 +19,7 @@
 
 #include "common.h"
 
+#include <pwd.h>
 #include <netdb.h>
 #include <netinet/in.h>
 #include <sys/socket.h>
@@ -30,70 +31,24 @@ struct list_t {
 	struct	list_t	*next;
 };
 
-static int old_do_enum(UPSCONN *ups, const char *varname)
-{
-	char	out[SMALLBUF], temp[SMALLBUF];
-
-	snprintf(out, sizeof(out), "ENUM %s\n", varname);
-
-	if (upscli_sendline(ups, out, strlen(out)) < 0) {
-		fprintf(stderr, "Enumerate %s failed: %s\n", 
-			varname, upscli_strerror(ups));
-
-		return -1;	/* failed */
-	}
-
-	if (upscli_readline(ups, temp, sizeof(temp)) < 0) {
-		fprintf(stderr, "Enumerate %s failed: %s\n",
-			varname, upscli_strerror(ups));
-
-		return -1;
-	}
-
-	if (strncmp(temp, "ENUM", 4) != 0) {
-		fprintf(stderr, "Bogus reply from server for %s\n", varname);
-		return -1;
-	}
-
-	if (upscli_readline(ups, temp, sizeof(temp)) < 0) {
-		fprintf(stderr, "Can't get next ENUM value: %s\n",
-			upscli_strerror(ups));
-
-		return -1;
-	}
-
-	while (strcmp(temp, "END") != 0) {
-		printf("Option: %s\n", strstr(temp, "\""));
-
-		if (upscli_readline(ups, temp, sizeof(temp)) < 0) {
-			fprintf(stderr, "Can't get next ENUM value: %s\n",
-				upscli_strerror(ups));
-	
-			return -1;
-		}
-	}
-
-	return 0;
-}
-
-static void usage(char *prog)
+static void usage(const char *prog)
 {
 	printf("Network UPS Tools upsrw %s\n\n", UPS_VERSION);
-        printf("usage: %s [-h]\n", prog);
+	printf("usage: %s [-h]\n", prog);
 	printf("       %s [-s <variable>] [-u <username>] [-p <password>] <ups>\n\n", prog);
 	printf("Demo program to set variables within UPS hardware.\n");
-        printf("\n");
-        printf("  -h            display this help text\n");
+	printf("\n");
+	printf("  -h            display this help text\n");
 	printf("  -s <variable>	specify variable to be changed\n");
 	printf("		use -s VAR=VALUE to avoid prompting for value\n");
-        printf("  -u <username> set username for command authentication\n");
-        printf("  -p <password> set password for command authentication\n");
-        printf("\n");
-        printf("  <ups>         UPS identifier - myups@localhost, etc.\n");
+	printf("  -u <username> set username for command authentication\n");
+	printf("  -p <password> set password for command authentication\n");
+	printf("\n");
+	printf("  <ups>         UPS identifier - <upsname>@<hostname>[:<port>]\n");
 	printf("\n");
 	printf("Call without -s to show all possible read/write variables.\n");
 
-	exit(0);
+	exit(EXIT_SUCCESS);
 }
 
 static void clean_exit(UPSCONN *ups, char *upsname, char *hostname, int code)
@@ -109,35 +64,7 @@ static void clean_exit(UPSCONN *ups, char *upsname, char *hostname, int code)
 	exit(code);
 }
 
-static int old_set(UPSCONN *ups, const char *upsname, const char *varname, 
-	const char *newval)
-{
-	char	temp[SMALLBUF];
-
-	if (upsname)
-		snprintf(temp, sizeof(temp), "SET %s@%s %s\n", 
-			varname, upsname, newval);
-	else
-		snprintf(temp, sizeof(temp), "SET %s %s\n", varname, newval);
-
-	if (upscli_sendline(ups, temp, strlen(temp)) < 0) {
-		fprintf(stderr, "Can't set variable: %s\n", 
-			upscli_strerror(ups));
-
-		return 1;
-	}
-
-	if (upscli_readline(ups, temp, sizeof(temp)) < 0) {
-		fprintf(stderr, "Set variable failed: %s\n", 
-			upscli_strerror(ups));
-
-		return 1;
-	}
-
-	return 0;
-}
-
-static int new_set(UPSCONN *ups, const char *upsname, const char *varname, 
+static int do_set(UPSCONN *ups, const char *upsname, const char *varname, 
 	const char *newval)
 {
 	char	buf[SMALLBUF], enc[SMALLBUF];
@@ -149,40 +76,54 @@ static int new_set(UPSCONN *ups, const char *upsname, const char *varname,
 		fprintf(stderr, "Can't set variable: %s\n", 
 			upscli_strerror(ups));
 
-		return 1;
+		return EXIT_FAILURE;
 	}
 
 	if (upscli_readline(ups, buf, sizeof(buf)) < 0) {
 		fprintf(stderr, "Set variable failed: %s\n", 
 			upscli_strerror(ups));
 
-		return 1;
+		return EXIT_FAILURE;
 	}
 
 	/* FUTURE: status cookies will tie in here */
 	if (strncmp(buf, "OK", 2) != 0) {
 		printf("Unexpected response from upsd: %s\n", buf);
-		return 1;
+		return EXIT_FAILURE;
 	}
 
-	return 0;
+	return EXIT_SUCCESS;
 }
 
 static int do_setvar(UPSCONN *ups, const char *varname, char *uin,
 		const char *pass, char *upsname, char *hostname)
 {
 	char	newval[SMALLBUF], temp[SMALLBUF], user[SMALLBUF], *ptr;
+	struct	passwd	*pw;
 
 	if (uin) {
 		snprintf(user, sizeof(user), "%s", uin);
 	} else {
+		memset(user, sizeof(user), '\0');
+
+		pw = getpwuid(getuid());
+
+		if (pw)
+			printf("Username (%s): ", pw->pw_name);
+		else
+			printf("Username: ");
 
-		printf("Username: ");
 		fgets(user, sizeof(user), stdin);
 
 		/* deal with that pesky newline */
 		if (strlen(user) > 1)
 			user[strlen(user) - 1] = '\0';
+		else {
+			if (!pw)
+				fatalx("No username available - even tried getpwuid");
+	
+			snprintf(user, sizeof(user), "%s", pw->pw_name);
+		}
 	}
 
 	/* leaks - use -p when running in valgrind */
@@ -192,7 +133,8 @@ static int do_setvar(UPSCONN *ups, const char *varname, char *uin,
 		if (!pass) {
 			fprintf(stderr, "getpass failed: %s\n", 
 				strerror(errno));
-			return 1;
+
+			return EXIT_FAILURE;
 		}
 	}
 
@@ -213,7 +155,7 @@ static int do_setvar(UPSCONN *ups, const char *varname, char *uin,
 		fprintf(stderr, "Can't set username: %s\n", 
 			upscli_strerror(ups));
 
-		return 1;
+		return EXIT_FAILURE;
 	}
 
 	if (upscli_readline(ups, temp, sizeof(temp)) < 0) {
@@ -224,13 +166,13 @@ static int do_setvar(UPSCONN *ups, const char *varname, char *uin,
 
 			fprintf(stderr, "You probably need to upgrade upsd.\n");
 
-			clean_exit(ups, upsname, hostname, 1);
+			clean_exit(ups, upsname, hostname, EXIT_FAILURE);
 		}
 
 		fprintf(stderr, "Set username failed: %s\n",
 			upscli_strerror(ups));
 
-		return 1;
+		return EXIT_FAILURE;
 	}
 
 	snprintf(temp, sizeof(temp), "PASSWORD %s\n", pass);
@@ -239,153 +181,36 @@ static int do_setvar(UPSCONN *ups, const char *varname, char *uin,
 		fprintf(stderr, "Can't set password: %s\n", 
 			upscli_strerror(ups));
 
-		return 1;
+		return EXIT_FAILURE;
 	}
 
 	if (upscli_readline(ups, temp, sizeof(temp)) < 0) {
 		fprintf(stderr, "Set password failed: %s\n", 
 			upscli_strerror(ups));
 
-		return 1;
+		return EXIT_FAILURE;
 	}
 
-	/* no upsname = fallback until 2.0 */
-	if (!upsname)
-		return old_set(ups, upsname, varname, newval);
+	/* no upsname means die */
+	if (!upsname) {
+		fprintf(stderr, "Error: a UPS name must be specified (upsname@hostname)\n");
+		return EXIT_FAILURE;
+	}
 
-	/* also fallback for old variable names */
-	if (!strchr(varname, '.'))
-		return old_set(ups, upsname, varname, newval);
+	/* old variable names are no longer supported */
+	if (!strchr(varname, '.')) {
+		fprintf(stderr, "Error: old variable names are not supported\n");
+		return EXIT_FAILURE;
+	}
 
-	return new_set(ups, upsname, varname, newval);
+	return do_set(ups, upsname, varname, newval);
 }	
 
-static int old_print_rwlist(UPSCONN *ups, char *upsname, char *hostname)
-{
-	int	typelen;
-	char	*v, *sp, *ptr, vars[SMALLBUF], out[SMALLBUF], temp[SMALLBUF],
-		*type;
-
-	printf("host: %s\n", hostname);
-
-	if (upscli_getlist(ups, upsname, UPSCLI_LIST_RW, vars, 
-		sizeof(vars)) < 0) {
-		fprintf(stderr, "Unable to get variable list - %s\n",
-		       upscli_strerror(ups));
-
-		return 1;
-	}
-
-	if (strlen(vars) == 0) {
-		fprintf(stderr, "Error: no read/write variables available\n");
-		return 1;
-	}
-
-	v = vars;
-	ptr = strchr(v, ' ');
-	if (!ptr) {
-		fprintf(stderr, "Broken string from server: %s\n", vars);
-		return 1;
-	}
-
-	while (v != NULL) {
-		ptr = strchr(v, ' ');
-		if (ptr)
-			*ptr++ = '\0';
-
-		/* get description */
-		snprintf(out, sizeof(out), "VARDESC %s\n", v);
-
-		if (upscli_sendline(ups, out, strlen(out)) < 0) {
-			fprintf(stderr, "Can't get description of %s: %s\n",
-				v, upscli_strerror(ups));
-			return 1;
-		}
-
-		if (upscli_readline(ups, temp, sizeof(temp)) < 0) {
-			fprintf(stderr, "Can't get description of %s: %s\n",
-				v, upscli_strerror(ups));
-			return 1;
-		}
-
-		printf("[%s] %s ", v, strstr(temp, "\""));
-
-		/* now get type */
-		snprintf(out, sizeof(out),
-			(upsname ? "VARTYPE %s@%s\n" : "VARTYPE %s\n"), v, upsname);
-
-		if (upscli_sendline(ups, out, strlen(out)) < 0) {
-			fprintf(stderr, "Can't get type of %s: %s\n",
-				v, upscli_strerror(ups));
-			return 1;
-		}
-
-		if (upscli_readline(ups, temp, sizeof(temp)) < 0) {
-			fprintf(stderr, "Can't get type of %s: %s\n",
-				v, upscli_strerror(ups));
-
-			return 1;
-		}
-
-		/* TYPE (ENUM|STRING) <num> */
-
-		sp = strchr(temp, ' ');
-		if ((!sp) || (strncmp(temp, "TYPE ", 5) != 0)) {
-			fprintf(stderr, "Unexpected response from server [%s]\n",
-				temp);
-
-			return 1;
-		}
-
-		*sp++ = '\0';
-
-		type = sp;
-
-		/* now make sure we can handle this vartype */
-
-		sp = strchr(type, ' ');
-
-		if (!sp) {
-			fprintf(stderr, "Unexpected vartype from server [%s]\n",
-				ptr);
-
-			return 1;
-		}
-		
-		*sp++ = '\0';
-
-		typelen = strtol(sp, (char **) NULL, 10);
-
-		printf("(%s:%d)\n", type, typelen);
-
-		if (!strcmp(type, "ENUM"))
-			if (old_do_enum(ups, v) != 0)
-				return 1;
-
-		if (!strcmp(type, "STRING")) {
-			if (upscli_getvar(ups, upsname, v, temp, 
-				sizeof(temp)) < 0) {
-
-				fprintf(stderr, "Can't get value of %s: %s\n",
-					temp, upscli_strerror(ups));
-
-				return 1;
-			}
-				
-			printf("Value: %s\n", temp);
-		}
-		
-		v = ptr;
-
-	}
-
-	return 0;
-}
-
 static const char *get_data(const char *type, UPSCONN *ups, 
 	const char *upsname, const char *varname)
 {
-	int	ret, numq, numa;
+	int	ret;
+	unsigned int	numq, numa;
 	char	**answer;
 	const	char	*query[4];
 
@@ -419,9 +244,10 @@ static void do_string(UPSCONN *ups, const char *upsname, const char *varname)
 	printf("Value: %s\n", val);
 }
 
-static void new_do_enum(UPSCONN *ups, const char *upsname, const char *varname)
+static void do_enum(UPSCONN *ups, const char *upsname, const char *varname)
 {
-	int	ret, numq, numa;
+	int	ret;
+	unsigned int	numq, numa;
 	char	**answer, *val;
 	const	char	*query[4], *tmp;
 
@@ -480,7 +306,8 @@ static void new_do_enum(UPSCONN *ups, const char *upsname, const char *varname)
 
 static void do_type(UPSCONN *ups, const char *upsname, const char *varname)
 {
-	int	i, ret, numq, numa;
+	int	ret;
+	unsigned int	i, numq, numa;
 	char	**answer;
 	const	char	*query[4];
 
@@ -500,7 +327,7 @@ static void do_type(UPSCONN *ups, const char *upsname, const char *varname)
 	for (i = 3; i < numa; i++) {
 
 		if (!strcasecmp(answer[i], "ENUM")) {
-			new_do_enum(ups, upsname, varname);
+			do_enum(ups, upsname, varname);
 			return;
 		}
 
@@ -536,13 +363,20 @@ static void print_rw(UPSCONN *ups, const char *upsname, const char *varname)
 	printf("\n");
 }	
 
-static int new_print_rwlist(UPSCONN *ups, char *upsname, char *hostname)
+static int print_rwlist(UPSCONN *ups, const char *upsname)
 {
-	int	ret, numq, numa;
+	int	ret;
+	unsigned int	numq, numa;
 	const	char	*query[2];
 	char	**answer;
 	struct	list_t	*lhead, *llast, *ltmp, *lnext;
 
+	/* the upsname is now required */
+	if (!upsname) {
+		fprintf(stderr, "Error: a UPS name must be specified (upsname@hostname)\n");
+		return EXIT_FAILURE;
+	}
+
 	llast = lhead = NULL;
 
 	query[0] = "RW";
@@ -554,11 +388,13 @@ static int new_print_rwlist(UPSCONN *ups, char *upsname, char *hostname)
 	if (ret < 0) {
 
 		/* old upsd --> fall back on old LISTRW technique */
-		if (upscli_upserror(ups) == UPSCLI_ERR_UNKCOMMAND)
-			return old_print_rwlist(ups, upsname, hostname);
+		if (upscli_upserror(ups) == UPSCLI_ERR_UNKCOMMAND) {
+			fprintf(stderr, "Error: upsd is too old to support this query\n");
+			return EXIT_FAILURE;
+		}
 
 		fprintf(stderr, "Error: %s\n", upscli_strerror(ups));
-		return 1;
+		return EXIT_FAILURE;
 	}
 
 	ret = upscli_list_next(ups, numq, query, &numa, &answer);
@@ -569,7 +405,7 @@ static int new_print_rwlist(UPSCONN *ups, char *upsname, char *hostname)
 		if (numa < 4) {
 			fprintf(stderr, "Error: insufficient data "
 				"(got %d args, need at least 4)\n", numa);
-			return 1;
+			return EXIT_FAILURE;
 		}
 
 		/* sock this entry away for later */
@@ -602,16 +438,21 @@ static int new_print_rwlist(UPSCONN *ups, char *upsname, char *hostname)
 		ltmp = lnext;
 	}
 
-	return 0;
+	return EXIT_SUCCESS;
 }
 
-static int print_rwlist(UPSCONN *ups, char *upsname, char *hostname)
+static void check_upsdef(const char *ups)
 {
-	/* no upsname = fall back on old methods until 2.0 */
-	if (!upsname)
-		return old_print_rwlist(ups, upsname, hostname);
+	char	*ptr;
 
-	return new_print_rwlist(ups, upsname, hostname);
+	ptr = strchr(ups, '@');
+
+	if (ptr)
+		return;
+
+	fprintf(stderr, "Error: invalid UPS definition.  Required format: upsname@hostname[:port]\n");
+
+	exit(EXIT_FAILURE);
 }
 
 int main(int argc, char **argv)
@@ -637,7 +478,7 @@ int main(int argc, char **argv)
 			break;
 		case 'V':
 			printf("Network UPS Tools upsrw %s\n", UPS_VERSION);
-			exit(0);
+			exit(EXIT_SUCCESS);
 		default:
 			usage(prog);
 			break;
@@ -650,11 +491,16 @@ int main(int argc, char **argv)
 	if (argc < 1)
 		usage(prog);
 
-	upscli_splitname(argv[0], &upsname, &hostname, &port);
+	check_upsdef(argv[0]);
+
+	upsname = hostname = NULL;
+
+	if (upscli_splitname(argv[0], &upsname, &hostname, &port) != 0)
+		clean_exit(&ups, upsname, hostname, EXIT_FAILURE);
 
 	if (upscli_connect(&ups, hostname, port, 0) < 0) {
 		fprintf(stderr, "Can't connect: %s\n", upscli_strerror(&ups));
-		clean_exit(&ups, upsname, hostname, 1);
+		clean_exit(&ups, upsname, hostname, EXIT_FAILURE);
 	}
 
 	/* setting a variable? */
@@ -666,10 +512,10 @@ int main(int argc, char **argv)
 	}
 
 	/* if not, get the list of supported read/write variables */
-	ret = print_rwlist(&ups, upsname, hostname);
+	ret = print_rwlist(&ups, upsname);
 
 	clean_exit(&ups, upsname, hostname, ret);
 
 	/* NOTREACHED */
-	return 0;
+	exit(EXIT_FAILURE);
 }
