@@ -61,7 +61,7 @@ typedef struct {
 	int	verbose = 0;		/* use for debugging */
 
 	struct  sigaction sa;
-	sigset_t us_sigmask;
+	sigset_t nut_upssched_sigmask;
 
 	/* ups name and notify type (string) as received from upsmon */
 	const	char	*upsname, *notify_type;
@@ -466,7 +466,7 @@ static int sock_read(struct conn_t *conn)
 
 		if (ret == -1) {
 			upslogx(LOG_NOTICE, "Parse error on sock: %s",
-				&conn->ctx.errmsg);
+				conn->ctx.errmsg);
 
 			return 0;	/* nothing parsed */
 		}
@@ -605,7 +605,7 @@ static int get_lock(const char *fn)
 }
 
 /* try to connect to bg process, and start one if necessary */
-static int check_parent(const char *cmd)
+static int check_parent(const char *cmd, const char *arg2)
 {
 	int	pipefd, lockfd, tries = 0;
 
@@ -619,9 +619,11 @@ static int check_parent(const char *cmd)
 		/* timer daemon isn't running */
 
 		/* it's not running, so there's nothing to cancel */
-		if (!strcmp(cmd, "CANCEL"))
+		if (!strcmp(cmd, "CANCEL") && (arg2 == NULL))
 			return PARENT_UNNECESSARY;
 
+		/* arg2 non-NULL means there is a cancel action available */
+
 		/* we need to start the daemon, so try to get the lock */
 
 		lockfd = get_lock(lockfn);
@@ -652,8 +654,8 @@ static void read_timeout(int sig)
 
 static void setup_sigalrm(void)
 {
-	sigemptyset(&us_sigmask);
-	sa.sa_mask = us_sigmask;
+	sigemptyset(&nut_upssched_sigmask);
+	sa.sa_mask = nut_upssched_sigmask;
 	sa.sa_flags = 0;
 	sa.sa_handler = read_timeout;
 	sigaction(SIGALRM, &sa, NULL);
@@ -682,7 +684,7 @@ static void sendcmd(const char *cmd, const char *arg1, const char *arg2)
 
 	for (i = 0; i < MAX_TRIES; i++) {
 
-		pipefd = check_parent(cmd);
+		pipefd = check_parent(cmd, arg2);
 
 		if (pipefd == PARENT_STARTED) {
 
@@ -873,7 +875,7 @@ static void checkconf(void)
 				snprintfcat(errmsg, sizeof(errmsg), " %s", 
 					ctx.arglist[i]);
 
-			upslogx(LOG_WARNING, errmsg);
+			upslogx(LOG_WARNING, "%s", errmsg);
 		}
 	}
 
