@@ -94,35 +94,67 @@ static int check_ups_fd(int do_report)
 	return 1;
 }	
 
-static void parse_var(const char *buf)
+static int get_var(const char *var, char *buf, size_t buflen, int verbose)
 {
-	char	ans[SMALLBUF];
+	int	ret;
+	unsigned int	numq, numa;
+	const	char	*query[4];
+	char	**answer;
 
 	if (!check_ups_fd(1))
-		return;
+		return 0;
 
-	if (upscli_getvar(&ups, upsname, buf, ans, sizeof(ans)) < 0) {
-		report_error();
-		return;
+	if (!upsname) {
+		if (verbose)
+			printf("[No UPS name specified]\n");
+
+		return 0;
 	}
 
-	printf("%s\n", ans);
+	query[0] = "VAR";
+	query[1] = upsname;
+	query[2] = var;
+
+	numq = 3;
+
+	ret = upscli_get(&ups, numq, query, &numa, &answer);
+
+	if (ret < 0) {
+		if (verbose)
+			report_error();
+		return 0;
+	}
+
+	if (numa < numq) {
+		if (verbose)
+			printf("[Invalid response]\n");
+		
+		return 0;
+	}
+
+	snprintf(buf, buflen, "%s", answer[3]);
+	return 1;
+}
+
+static void parse_var(const char *var)
+{
+	char	answer[SMALLBUF];
+
+	if (!get_var(var, answer, sizeof(answer), 1))
+		return;
+
+	printf("%s\n", answer);
 }
 
 static void do_status(void)
 {
 	int	i;
-	char	stat[SMALLBUF], *sp, *ptr;
+	char	status[SMALLBUF], *sp, *ptr;
 
-	if (!check_ups_fd(1))
+	if (!get_var("ups.status", status, sizeof(status), 1))
 		return;
 
-	if (upscli_getvar(&ups, upsname, "status", stat, sizeof(stat)) < 0) {
-		report_error();
-		return;
-	}
-
-	sp = stat;
+	sp = status;
 
 	while (sp) {
 		ptr = strchr(sp, ' ');
@@ -154,16 +186,11 @@ static int do_date(const char *buf)
 
 static int get_img_val(const char *var, const char *desc, const char *imgargs)
 {
-	char	temp[SMALLBUF];
+	char	answer[SMALLBUF];
 
-	if (!check_ups_fd(1))
+	if (!get_var(var, answer, sizeof(answer), 1))
 		return 1;
 
-	if (upscli_getvar(&ups, upsname, var, temp, sizeof(temp)) < 0) {
-		report_error();
-		return 1;
-	}
-
 	printf("<IMG SRC=\"upsimage.cgi?host=%s&amp;display=%s",
 		currups->sys, var);
 
@@ -171,7 +198,7 @@ static int get_img_val(const char *var, const char *desc, const char *imgargs)
 		printf("&amp;%s", imgargs);
 
 	printf("\" WIDTH=\"100\" HEIGHT=\"350\" ALT=\"%s: %s\">\n",
-		desc, temp);
+		desc, answer);
 
 	return 1;
 }
@@ -242,26 +269,28 @@ static int do_img(char *buf)
 		split_imgarg(ptr, imgargs, sizeof(imgargs));
 	}
 
-	if (!strcmp(type, "BATTVOLT"))
-		return get_img_val("battvolt", "Battery Voltage", imgargs);
+	/* only allow known types through */
 
-	if (!strcmp(type, "BATTPCT"))
-		return get_img_val("battpct", "Battery Charge", imgargs);
+	if (!strcmp(type, "input.voltage"))
+		return get_img_val("input.voltage", "Input voltage", imgargs);
 
-	if (!strcmp(type, "UTILITY"))
-		return get_img_val("utility", "Utility", imgargs);
+	if (!strcmp(type, "battery.voltage"))
+		return get_img_val("battery.voltage", "Battery voltage", imgargs);
 
-	if (!strcmp(type, "OUTVOLT"))
-		return get_img_val("outvolt", "Output Voltage", imgargs);
+	if (!strcmp(type, "battery.charge"))
+		return get_img_val("battery.charge", "Battery charge", imgargs);
 
-	if (!strcmp(type, "LOADPCT"))
-		return get_img_val("loadpct", "UPS Load", imgargs);
+	if (!strcmp(type, "output.voltage"))
+		return get_img_val("output.voltage", "Output voltage", imgargs);
 
-	if (!strcmp(type, "ACFREQ"))
-		return get_img_val("acfreq", "AC Freq", imgargs);
+	if (!strcmp(type, "ups.load"))
+		return get_img_val("ups.load", "UPS load", imgargs);
 
-	if (!strcmp(type, "OUT_FREQ"))
-		return get_img_val("out_freq", "Out Freq", imgargs);
+	if (!strcmp(type, "input.frequency"))
+		return get_img_val("input.frequency", "Input frequency", imgargs);
+
+	if (!strcmp(type, "output.frequency"))
+		return get_img_val("output.frequency", "Output frequency", imgargs);
 
 	return 0;
 }
@@ -282,7 +311,15 @@ static void ups_connect(void)
 		}
 
 		/* see if it's just on the same host */
-		upscli_splitname(currups->sys, &newups, &newhost, &newport);
+		newups = newhost = NULL;
+
+		if (upscli_splitname(currups->sys, &newups, &newhost, 
+			&newport) != 0) {
+			printf("Unusable UPS definition [%s]\n", currups->sys);
+			fprintf(stderr, "Unusable UPS definition [%s]\n", 
+				currups->sys);
+			exit(EXIT_FAILURE);
+		}		
 
 		if ((!strcmp(newhost, hostname)) && (port == newport)) {
 			free(upsname);
@@ -305,7 +342,12 @@ static void ups_connect(void)
 	if (hostname)
 		free(hostname);
 
-	upscli_splitname(currups->sys, &upsname, &hostname, &port);
+	if (upscli_splitname(currups->sys, &upsname, &hostname, &port) != 0) {
+		printf("Unusable UPS definition [%s]\n", currups->sys);
+		fprintf(stderr, "Unusable UPS definition [%s]\n", 
+			currups->sys);
+		exit(EXIT_FAILURE);
+	}
 
 	if (upscli_connect(&ups, hostname, port, 0) < 0)
 		fprintf(stderr, "UPS [%s]: can't connect to server: %s\n",
@@ -324,33 +366,30 @@ static void do_hostlink(void)
 }
 
 /* see if the UPS supports this variable - skip to the next ENDIF if not */
-static void do_ifsupp(char *var)
+static void do_ifsupp(const char *var)
 {
-	char	ans[SMALLBUF];
+	char	dummy[SMALLBUF];
 
-	/* if not connected, assume it's not supported to skip more */
+	/* if not connected, act like it's not supported and skip the rest */
 	if (!check_ups_fd(0)) {
 		skip_to_endif = 1;
 		return;
-	}		
+	}
 
-	if (upscli_getvar(&ups, upsname, var, ans, sizeof(ans)) < 0)
+	if (!get_var(var, dummy, sizeof(dummy), 0)) {
 		skip_to_endif = 1;
+		return;
+	}
 }
 
-static void do_temp(char *var)
+static void do_temp(const char *var)
 {
 	char	tempc[SMALLBUF];
 	float	tempf;
 
-	if (!check_ups_fd(1))
+	if (!get_var(var, tempc, sizeof(tempc), 1))
 		return;
 
-	if (upscli_getvar(&ups, upsname, var, tempc, sizeof(tempc)) < 0) {
-		report_error();
-		return;
-	}
-
 	if (use_celsius) {
 		printf("%s\n", tempc);
 		return;
@@ -383,8 +422,7 @@ static void do_statuscolor(void)
 		return;
 	}
 
-	if (upscli_getvar(&ups, upsname, "status", stat, sizeof(stat)) < 0) {
-
+	if (!get_var("ups.status", stat, sizeof(stat), 0)) {
 		/* status not available - give yellow as a warning */
 		printf("#FFFF00\n");
 		return;
@@ -428,8 +466,7 @@ static void do_utilitycolor(void)
 		return;
 	}
 
-	if (upscli_getvar(&ups, upsname, "utility", tmp, sizeof(tmp)) < 0) {
-
+	if (!get_var("input.voltage", tmp, sizeof(tmp), 0)) {
 		/* nothing available - default is green */
 		printf("#00FF00\n");
 		return;
@@ -437,18 +474,18 @@ static void do_utilitycolor(void)
 
 	utility = strtol(tmp, (char **) NULL, 10);
 
-	if (upscli_getvar(&ups, upsname, "lowxfer", tmp, sizeof(tmp)) < 0) {
+	if (!get_var("input.transfer.low", tmp, sizeof(tmp), 0)) {
 
-		/* no lowxfer?  default to green */
+		/* not available = default to green */
 		printf("#00FF00\n");
 		return;
 	}
 
 	lowxfer = strtol(tmp, (char **) NULL, 10);
 
-	if (upscli_getvar(&ups, upsname, "highxfer", tmp, sizeof(tmp)) < 0) {
+	if (!get_var("input.transfer.high", tmp, sizeof(tmp), 0)) {
 
-		/* same idea for highxfer */
+		/* same idea */
 		printf("#00FF00\n");
 		return;
 	}
@@ -470,7 +507,7 @@ static int parse_line(const char *buf)
 	if (strlen(buf) < 3) {
 
 		if (skip_to_endif == 1)
-                        return 1;
+			return 1;
 
 		return 0;
 	}
@@ -600,12 +637,12 @@ static int parse_line(const char *buf)
 	}
 
 	if (!strcmp(cmd, "UPSTEMP")) {
-		do_temp("UPSTEMP");
+		do_temp("ups.temperature");
 		return 1;
 	}
 
 	if (!strcmp(cmd, "AMBTEMP")) {
-		do_temp("AMBTEMP");
+		do_temp("ambient.temperature");
 		return 1;
 	}
 
@@ -631,7 +668,7 @@ static void display_template(const char *tfn)
 
 		printf("Error: can't open template file (%s)\n", tfn);
 
-		exit(1);
+		exit(EXIT_FAILURE);
 	}
 
 	while (fgets(buf, sizeof(buf), tf)) {
@@ -668,7 +705,7 @@ static void add_ups(char *sys, char *desc)
 }
 
 /* called for fatal errors in parseconf like malloc failures */
-void upsstats_hosts_err(const char *errmsg)
+static void upsstats_hosts_err(const char *errmsg)
 {
 	upslogx(LOG_ERR, "Fatal error in parseconf(hosts.conf): %s", errmsg);
 }
@@ -695,7 +732,7 @@ static void load_hosts_conf(void)
 
 		/* leave something for the admin */
 		fprintf(stderr, "upsstats: %s\n", ctx.errmsg);
-		exit(0);
+		exit(EXIT_FAILURE);
 	}
 
 	while (pconf_file_next(&ctx)) {
@@ -722,7 +759,7 @@ static void display_single(void)
 	if (!checkhost(monhost, &monhostdesc)) {
 		printf("Access to that host [%s] is not authorized.\n",
 			monhost);
-		exit(0);
+		exit(EXIT_FAILURE);
 	}
 
 	add_ups(monhost, monhostdesc);
@@ -746,7 +783,7 @@ int main(int argc, char **argv)
 	/* if a host is specified, use upsstats-single.html instead */
 	if (monhost) {
 		display_single();
-		exit(0);
+		exit(EXIT_SUCCESS);
 	}
 
 	/* default: multimon replacement mode */
