@@ -97,19 +97,20 @@
 #define STATE_ENDOFLINE		7
 #define STATE_PARSEERR		8
 
-static void pconf_fatal(PCONF_CTX *ctx, char *errtxt)
+static void pconf_fatal(PCONF_CTX *ctx, const char *errtxt)
 {
 	if (ctx->errhandler)
 		ctx->errhandler(errtxt);
 	else
 		fprintf(stderr, "parseconf: fatal error: %s\n", errtxt);
 
-	exit(1);
+	exit(EXIT_FAILURE);
 }
 
 static void add_arg_word(PCONF_CTX *ctx)
 {
 	int	argpos;
+	size_t	wbuflen;
 
 	/* this is where the new value goes */
 	argpos = ctx->numargs;
@@ -138,12 +139,14 @@ static void add_arg_word(PCONF_CTX *ctx)
 		ctx->argsize[argpos] = 0;
 	}
 
+	wbuflen = strlen(ctx->wordbuf);
+
 	/* now see if the string itself grew compared to last time */
-	if (strlen(ctx->wordbuf) >= ctx->argsize[argpos]) {
-		int	newlen;
+	if (wbuflen >= ctx->argsize[argpos]) {
+		size_t	newlen;
 
 		/* allow for the trailing NULL */
-		newlen = strlen(ctx->wordbuf) + 1;
+		newlen = wbuflen + 1;
 
 		/* expand the string storage */
 		ctx->arglist[argpos] = realloc(ctx->arglist[argpos], newlen);
@@ -159,13 +162,17 @@ static void add_arg_word(PCONF_CTX *ctx)
 	memset(ctx->arglist[argpos], '\0', ctx->argsize[argpos]);
 
 	/* finally copy the new value into the provided space */
-	strncpy(ctx->arglist[argpos], ctx->wordbuf, strlen(ctx->wordbuf));
+	strncpy(ctx->arglist[argpos], ctx->wordbuf, wbuflen);
 }
 
 static void addchar(PCONF_CTX *ctx)
 {
+	size_t	wbuflen;
+
+	wbuflen = strlen(ctx->wordbuf);
+
 	if (ctx->wordlen_limit != 0) {
-		if (strlen(ctx->wordbuf) >= ctx->wordlen_limit) {
+		if (wbuflen >= ctx->wordlen_limit) {
 
 			/* limit reached: don't append any more */
 			return;
@@ -173,8 +180,8 @@ static void addchar(PCONF_CTX *ctx)
 	}
 
 	/* allow for the null */
-	if (strlen(ctx->wordbuf) >= (ctx->wordbufsize - 1)) {
-		ctx->wordbufsize++;
+	if (wbuflen >= (ctx->wordbufsize - 1)) {
+		ctx->wordbufsize += 8;
 
 		ctx->wordbuf = realloc(ctx->wordbuf, ctx->wordbufsize);
 
@@ -182,7 +189,7 @@ static void addchar(PCONF_CTX *ctx)
 			pconf_fatal(ctx, "realloc wordbuf failed");
 
 		/* repoint as wordbuf may have moved */
-		ctx->wordptr = &ctx->wordbuf[strlen(ctx->wordbuf)];
+		ctx->wordptr = &ctx->wordbuf[wbuflen];
 	}
 
 	*ctx->wordptr++ = ctx->ch;
@@ -342,7 +349,7 @@ static int collectliteral(PCONF_CTX *ctx)
 /* clean up memory before going back to the user */
 static void free_storage(PCONF_CTX *ctx)
 {
-	int	i;
+	unsigned int	i;
 
 	if (ctx->wordbuf)
 		free(ctx->wordbuf);
@@ -520,7 +527,7 @@ int pconf_file_next(PCONF_CTX *ctx)
 /* parse a provided line */
 int pconf_line(PCONF_CTX *ctx, const char *line)
 {
-	int	i;
+	size_t	i, linelen;
 
 	if (!check_magic(ctx))
 		return 0;
@@ -531,7 +538,9 @@ int pconf_line(PCONF_CTX *ctx, const char *line)
 	ctx->numargs = 0;
 	ctx->state = STATE_FINDWORDSTART;
 
-	for (i = 0; i < strlen(line); i++) {
+	linelen = strlen(line);
+
+	for (i = 0; i < linelen; i++) {
 		ctx->ch = line[i];
 
 		parse_char(ctx);
@@ -556,7 +565,7 @@ int pconf_line(PCONF_CTX *ctx, const char *line)
 
 char *pconf_encode(const char *src, char *dest, size_t destsize)
 {
-	int	i, len = 0, maxlen;
+	size_t	i, srclen, destlen, maxlen;
 
 	if (destsize < 1)
 		return dest;
@@ -565,22 +574,24 @@ char *pconf_encode(const char *src, char *dest, size_t destsize)
 
 	/* always leave room for a final NULL */
 	maxlen = destsize - 1;
+	srclen = strlen(src);
+	destlen = 0;
 
-	for (i = 0; i < strlen(src); i++) {
+	for (i = 0; i < srclen; i++) {
 		if (strchr(PCONF_ESCAPE, src[i])) {
 
 			/* if they both won't fit, we're done */
-			if (len >= maxlen - 1)
+			if (destlen >= maxlen - 1)
 				return dest;
 
-			dest[len++] = '\\';
+			dest[destlen++] = '\\';
 		}
 
 		/* bail out when dest is full */
-		if (len >= maxlen)
+		if (destlen >= maxlen)
 			return dest;
 
-		dest[len++] = src[i];
+		dest[destlen++] = src[i];
 	}
 
 	return dest;
