@@ -366,7 +366,8 @@ static void do_capabilities(void)
 			snprintf(etmp, entlen + 1, "%s", entptr);
 
 			if (vt && ((loc == upsloc) || (loc == '4')))
-				dstate_addenum(vt->name, convert_data(vt, etmp));
+				dstate_addenum(vt->name, "%s",
+					convert_data(vt, etmp));
 
 			entptr += entlen;
 		}
@@ -651,7 +652,8 @@ static int do_cal(int start)
 		ret = read_buf(temp, sizeof(temp));
 
 		if ((ret < 1) || (!strcmp(temp, "NA")) || (!strcmp(temp, "NO"))) {
-			upslogx(LOG_WARNING, "Stop calibration failed", temp);
+			upslogx(LOG_WARNING, "Stop calibration failed: %s", 
+				temp);
 			return STAT_INSTCMD_HANDLED;	/* FUTURE: failure */
 		}
 
@@ -677,7 +679,7 @@ static int do_cal(int start)
 	ret = read_buf(temp, sizeof(temp));
 
 	if ((ret < 1) || (!strcmp(temp, "NA")) || (!strcmp(temp, "NO"))) {
-		upslogx(LOG_WARNING, "Start calibration failed", temp);
+		upslogx(LOG_WARNING, "Start calibration failed: %s", temp);
 		return STAT_INSTCMD_HANDLED;	/* FUTURE: failure */
 	}
 
