@@ -199,7 +199,7 @@ static void pollfail(const char *why)
 
 	/* ignore the first few since these UPSes tend to drop characters */
 	if (poll_failures == 3)
-		upslogx(LOG_ERR, why);
+		upslogx(LOG_ERR, "%s", why);
 
 	return;
 }
