@@ -357,7 +357,7 @@ void upsdrv_updateinfo(void)
 
 	ser_comm_good();
 
-	dstate_setinfo("input.frequency",  "%2.1f", frequency(buf[7]));
+	dstate_setinfo("input.frequency", "%2.1f", frequency(buf[7]));
 	dstate_setinfo("ups.temperature", "%2.1f", tempconvert(buf[6]));
 	dstate_setinfo("battery.charge", "%03d", battconvert(buf[5]));
 	dstate_setinfo("ups.load", "%03d", (buf[3] & 0xff) * 2);
@@ -553,7 +553,7 @@ void upsdrv_initinfo(void)
 		exit(EXIT_FAILURE);
 	}
 
-	dstate_setinfo("ups.mfr", "CyberPower", 0, 0);
+	dstate_setinfo("ups.mfr", "CyberPower");
 	dstate_setinfo("driver.version.internal", "%s", DRV_VERSION);
 
 	/* poll once to put in some good data */
