@@ -23,6 +23,11 @@
 
 #include <asm/types.h>
 #include <sys/ioctl.h>
+
+#ifndef HID_MAX_USAGES
+#define HID_MAX_USAGES 1024	/* horrible workaround hack */
+#endif
+
 #include <linux/hiddev.h>
 #include <fcntl.h>
 #include <stdio.h>
@@ -313,8 +318,8 @@ void upsdrv_initinfo(void)
 	rtrim(HWVERS, ' ');
 
 	dstate_setinfo("driver.version.internal", "%s", DRV_VERSION);
-	dstate_setinfo("ups.mfr", MANUFR);
-	dstate_setinfo("ups.model", MDLNUM);
+	dstate_setinfo("ups.mfr", "%s", MANUFR);
+	dstate_setinfo("ups.model", "%s", MDLNUM);
 
 	dstate_setinfo("input.transfer.low", "%d", LOXFER);
 	dstate_setinfo("input.transfer.high", "%d", HIXFER);
