@@ -434,7 +434,7 @@ static int instcmd(const char *cmdname, const char *extra)
         if (!strcasecmp(cmdname, "shutdown.return")) {
 		snprintf(aux, sizeof(aux), "S%sR%s\r", 
 			strdelayshut, strwakedelay);
-		ret = ser_send_pace(upsfd, SENDDELAY, aux);
+		ret = ser_send_pace(upsfd, SENDDELAY, "%s", aux);
              
 		upslogx(LOG_INFO,"Sending shutdown command '%s' to UPS", aux);
 		return STAT_INSTCMD_HANDLED;
@@ -442,7 +442,7 @@ static int instcmd(const char *cmdname, const char *extra)
 
         if (!strcasecmp(cmdname, "shutdown.stayoff")) {
 		snprintf(aux, sizeof(aux), "S%sR0000\r", strdelayshut);
-		ret = ser_send_pace(upsfd, SENDDELAY, aux);
+		ret = ser_send_pace(upsfd, SENDDELAY, "%s", aux);
 
 		upslogx(LOG_INFO,"Sending shutdown command '%s' to UPS", aux);
 		return STAT_INSTCMD_HANDLED;
@@ -508,21 +508,13 @@ void upsdrv_initinfo(void)
     dstate_setinfo("driver.version.internal", "%s", DRIVERVERSION);
 
   /* Q1 Query */ 
-    dstate_setinfo( "ups.mfr", UPSMFR); /* INFO_MFR*/
-    dstate_setinfo( "ups.model", UPSTYPE); /*INFO_MODEL*/
-    dstate_setinfo( "ups.firmware", UPSFIRM); /* INFO_FIRMREV */
-    dstate_setinfo( "input.voltage", "220");  /*INFO_UTILITY */  /* Q1 VOLTAJE ENTRADA 0 */
-    dstate_setinfo( "output.voltage.target.line", "220" ); /* INFO_NOM_IN_VOLT*/ /* VOLTAJE A ENTRADA 1 */  
-    dstate_setinfo( "battery.voltage", "12");  /* INFO_BATTVOLT */ /* Q1 VOLTAJE BATERIA(S) 5 */
+    dstate_setinfo( "ups.mfr", "%s", UPSMFR); /* INFO_MFR*/
+    dstate_setinfo( "ups.model", "%s", UPSTYPE); /*INFO_MODEL*/
+    dstate_setinfo( "ups.firmware", "%s", UPSFIRM); /* INFO_FIRMREV */
 /*    dstate_setinfo( INFO_STATUS, "");    DUDA  */
-    dstate_setinfo( "input.frequency", "50");  /* INFO_ACFREQ  */  /* Q1 FRECUENCIA ENTRADA 4 */
-    dstate_setinfo( "ups.load", "0" ); /* INFO_LOADPCT */    /* Q1 CARGA UPS 3 */
-    dstate_setinfo( "ups.temperature", "0");  /* INFO_UPSTEMP */  /* Q1 TEMPERATURA 6 */ 
-    dstate_setinfo( "output.voltage", "220");  /* INFO_OUTVOLT */  /* Q1 VOLTAJE SALIDA 2 */
   
   /* F query */
     dstate_setinfo( "output.voltage.target.battery", "220" ); /* INFO_OUTVLTSEL */ /*  F VOLTAJE NOMINAL DE SALIDA 0 */
-    dstate_setinfo( "output.curent", "0" );   /* INFO_CURRENT */  /*  F AMPERIOS SALIDA  1 */
     dstate_setinfo( "battery.voltage.nominal", "12"); /* INFO_NOMBATVLT */   /*  F VOLTAJE NOMINAL DE BATERIA 2 */
 
     dstate_setinfo( "ups.delay.shutdown", "%s", strdelayshut); /* INFO_DELAYSHUT */
@@ -532,7 +524,6 @@ void upsdrv_initinfo(void)
     dstate_setflags("ups.delay.start", ST_FLAG_RW | ST_FLAG_STRING );
     dstate_setaux  ("ups.delay.start", 4);
     
-    dstate_setinfo( "battery.charge", "00");      /* INFO_BATTPCT */
 
     dstate_addcmd("shutdown.stop"); /* (INFO_INSTCMD, "", 0, CMD_STOPSHUTD);*/
     dstate_addcmd("test.battery.start"); /* (INFO_INSTCMD, "", 0, CMD_SHUTDOWN);*/
