@@ -50,10 +50,11 @@
       correctly connected to the serial port).
  */
 
-#define DRV_VERSION "0.02"
+#define DRV_VERSION "0.03"
 
 #include <sys/ioctl.h>
 #include "main.h"
+#include "serial.h"
 
 static int
 etapro_get_response(const char *resp_type)
@@ -63,7 +64,7 @@ etapro_get_response(const char *resp_type)
 	int ret;
 	unsigned int val;
 
-	ret = upsrecv(tmp, sizeof(tmp), '\n', "");
+	ret = ser_get_line(upsfd, tmp, sizeof(tmp), '\n', "", 3, 0);
 	if (ret < 0) {
 		upslogx(LOG_ERR, "no response from UPS");
 		return -1;
@@ -103,7 +104,7 @@ etapro_set_on_timer(int seconds)
 	int x;
 
 	if (seconds == 0) {  /* cancel the running timer */
-		upssend("RS\r");
+		ser_send(upsfd, "RS\r");
 		x = etapro_get_response("SV");
 		if (x == 0x30)
 			return;  /* OK */
@@ -118,7 +119,7 @@ etapro_set_on_timer(int seconds)
 			printf("UPS on in %d seconds\n", seconds);
 		}
 
-		upssend("RN%04X\r", seconds);
+		ser_send(upsfd, "RN%04X\r", seconds);
 		x = etapro_get_response("SV");
 		if (x == 0x20)
 			return;  /* OK */
@@ -132,7 +133,7 @@ etapro_set_off_timer(int seconds)
 	int x;
 
 	if (seconds == 0) {  /* cancel the running timer */
-		upssend("RR\r");
+		ser_send(upsfd, "RR\r");
 		x = etapro_get_response("SV");
 		if (x == 0x10)
 			return;  /* OK */
@@ -147,7 +148,7 @@ etapro_set_off_timer(int seconds)
 			printf("UPS off in %d seconds\n", seconds);
 		}
 
-		upssend("RO%04X\r", seconds);
+		ser_send(upsfd, "RO%04X\r", seconds);
 		x = etapro_get_response("SV");
 		if (x == 0)
 			return;  /* OK */
@@ -155,7 +156,7 @@ etapro_set_off_timer(int seconds)
 	upslogx(LOG_ERR, "etapro_set_off_timer: error, status=0x%02x", x);
 }
 
-int instcmd(const char *cmdname, const char *extra)
+static int instcmd(const char *cmdname, const char *extra)
 {
 	if (!strcasecmp(cmdname, "load.off")) {
 		etapro_set_off_timer(1);
@@ -184,13 +185,13 @@ upsdrv_initinfo(void)
 	dstate_addcmd("shutdown.return");
 
 	/* First command after power on returns junk - ignore it.  */
-	upssend("RI\r");
+	ser_send(upsfd, "RI\r");
 	sleep(1);
-	upsflushin(1, nut_debug_level, "");
+	ser_flush_in(upsfd, "", nut_debug_level);
 
 	upsdrv_updateinfo();
 
-	upsh.new_instcmd = instcmd;
+	upsh.instcmd = instcmd;
 }
 
 void
@@ -200,7 +201,7 @@ upsdrv_updateinfo(void)
 	int x, flags;
 	double utility, outvolt, battvolt, loadpct;
 
-	upssend("RI\r");  /* identify */
+	ser_send(upsfd, "RI\r");  /* identify */
 
 	x = etapro_get_response("SR");  /* manufacturer */
 	if (x < 0) {
@@ -223,7 +224,7 @@ upsdrv_updateinfo(void)
 		return;
 	}
 
-	upssend("RP\r");  /* read measurements */
+	ser_send(upsfd, "RP\r");  /* read measurements */
 
 	x = etapro_get_response("SO");  /* status flags */
 	if (x < 0) {
@@ -347,11 +348,14 @@ upsdrv_initups(void)
 	int dtr_bit = TIOCM_DTR;
 	int rts_bit = TIOCM_RTS;
 
-	open_serial(device_path, B1200);
+	upsfd = ser_open(device_path);
+	ser_set_speed(upsfd, device_path, B1200);
+
 	ioctl(upsfd, TIOCMBIC, &dtr_bit);
 	ioctl(upsfd, TIOCMBIS, &rts_bit);
 }
 
 void upsdrv_cleanup(void)
 {
+	ser_close(upsfd, device_path);
 }
