@@ -81,5 +81,18 @@ struct {
 	{ "WELI 500 1.0", "Giant Power", "MT650", 10.6, 3.7, 170, 180, 270, 280, 0 },
 	{ "SMART-UPS       1800VA     T18Q16AG", "Effekta", "MT 2000 RM",
 		50.0, 19.5, 171, 200, 260, 278, 1 },
+
+	/* SuperPower model data from Denis Zaika */
+
+	{ "----            ----       VS00024Q", "SuperPower", "HP360", 9.6, 
+		3.9, 140, 190, 240, 280, 1 },
+	{ " -------------   ------     VS000391", "SuperPower", "Hope-550", 
+		9.6, 3.9, 170, 190, 240, 280, 0 },
+
+	/* Unitek data from Antoine Cuvellard */
+	        
+	{ "UNITEK          Alph1000iS A0", "Unitek", "Alpha 1000is",
+		9.6, 2.4, 158, 172, 288, 290, 0 },
+
 	{ NULL,    NULL,		NULL,  0, 0,   0,   0,   0,   0, 0 }
 };
