@@ -75,17 +75,17 @@ void upsdrv_initinfo(void)
 	/* setup the basics */
 
 	if (getval("mfr"))
-		dstate_setinfo("ups.mfr", getval("mfr"));
+		dstate_setinfo("ups.mfr", "%s", getval("mfr"));
 	else
-		dstate_setinfo("ups.mfr", upstab[upstype].mfr);
+		dstate_setinfo("ups.mfr", "%s", upstab[upstype].mfr);
 
 	if (getval("model"))
-		dstate_setinfo("ups.model", getval("model"));
+		dstate_setinfo("ups.model", "%s", getval("model"));
 	else
-		dstate_setinfo("ups.model", upstab[upstype].model);
+		dstate_setinfo("ups.model", "%s", upstab[upstype].model);
 
 	if (getval("serial"))
-		dstate_setinfo("ups.serial", getval("serial"));
+		dstate_setinfo("ups.serial", "%s", getval("serial"));
 
 	dstate_setinfo("driver.version.internal", "%s", DRV_VERSION);
 
