@@ -1,7 +1,7 @@
 
 #include <usb.h> /* libusb */
 
-extern int libusb_open(HIDDevice *curDevice, MatchFlags *flg, unsigned char *ReportDesc);
+extern int libusb_open(HIDDevice *curDevice, MatchFlags *flg, unsigned char *ReportDesc, int mode);
 void libusb_close(HIDDevice *curDevice);
 
 extern usb_dev_handle *udev;
