@@ -57,11 +57,11 @@ void ResetParser(HIDParser* pParser)
  * Return pointer on current offset value for Report designed by 
  * ReportID/ReportType
  * -------------------------------------------------------------------------- */
-static uchar* GetReportOffset(HIDParser* pParser, 
-                       const uchar ReportID, 
-                       const uchar ReportType)
+static u_char* GetReportOffset(HIDParser* pParser, 
+                       const u_char ReportID, 
+                       const u_char ReportType)
 {
-  ushort Pos=0;
+  u_short Pos=0;
   while(Pos<MAX_REPORT && pParser->OffsetTab[Pos][0]!=0)
   {
     if(pParser->OffsetTab[Pos][0]==ReportID 
@@ -82,10 +82,10 @@ static uchar* GetReportOffset(HIDParser* pParser,
 }
 
 /*
- * FormatValue(long Value, uchar Size)
+ * FormatValue(long Value, u_char Size)
  * Format Value to fit with long format with respect of negative values
  * -------------------------------------------------------------------------- */
-static long FormatValue(long Value, uchar Size)
+static long FormatValue(long Value, u_char Size)
 {
   if(Size==1) 
     Value=(long)(char)Value;
@@ -137,19 +137,19 @@ int HIDParse(HIDParser* pParser, HIDData* pData)
       case ITEM_UPAGE :
       {
         /* Copy UPage in Usage stack */
-        pParser->UPage=(ushort)pParser->Value;
+        pParser->UPage=(u_short)pParser->Value;
         break;
       }
       case ITEM_USAGE :
       {
         /* Copy global or local UPage if any, in Usage stack */
          if((pParser->Item & SIZE_MASK)>2)
-          pParser->UsageTab[pParser->UsageSize].UPage=(ushort)(pParser->Value>>16);
+          pParser->UsageTab[pParser->UsageSize].UPage=(u_short)(pParser->Value>>16);
         else
           pParser->UsageTab[pParser->UsageSize].UPage=pParser->UPage;
 
         /* Copy Usage in Usage stack */
-        pParser->UsageTab[pParser->UsageSize].Usage=(ushort)(pParser->Value & 0xFFFF);
+        pParser->UsageTab[pParser->UsageSize].Usage=(u_short)(pParser->Value & 0xFFFF);
 
         /* Increment Usage stack size */
         pParser->UsageSize++;
@@ -166,7 +166,7 @@ int HIDParse(HIDParser* pParser, HIDData* pData)
         /* Unstack UPage/Usage from UsageTab (never remove the last) */
         if(pParser->UsageSize>0)
         {
-          uchar ii=0;
+          u_char ii=0;
           while(ii<pParser->UsageSize)
           {
             pParser->UsageTab[ii].Usage=pParser->UsageTab[ii+1].Usage;
@@ -219,7 +219,7 @@ int HIDParse(HIDParser* pParser, HIDData* pData)
         /* Unstack UPage/Usage from UsageTab (never remove the last) */
         if(pParser->UsageSize>0)
         {
-          uchar ii=0;
+          u_char ii=0;
           while(ii<pParser->UsageSize)
           {
             pParser->UsageTab[ii].UPage=pParser->UsageTab[ii+1].UPage;
@@ -231,13 +231,13 @@ int HIDParse(HIDParser* pParser, HIDData* pData)
         }
 
         /* Copy data type */
-        pParser->Data.Type=(uchar)(pParser->Item & ITEM_MASK);
+        pParser->Data.Type=(u_char)(pParser->Item & ITEM_MASK);
 
         /* Copy data attribute */
-        pParser->Data.Attribute=(uchar)pParser->Value;
+        pParser->Data.Attribute=(u_char)pParser->Value;
 
         /* Store offset */
-        pParser->Data.Offset=*GetReportOffset(pParser, pParser->Data.ReportID, (uchar)(pParser->Item & ITEM_MASK));
+        pParser->Data.Offset=*GetReportOffset(pParser, pParser->Data.ReportID, (u_char)(pParser->Item & ITEM_MASK));
     
         /* Get Object in pData */
         /* -------------------------------------------------------------------------- */
@@ -245,7 +245,7 @@ int HIDParse(HIDParser* pParser, HIDData* pData)
         /* -------------------------------------------------------------------------- */
 
         /* Increment Report Offset */
-        *GetReportOffset(pParser, pParser->Data.ReportID, (uchar)(pParser->Item & ITEM_MASK)) += pParser->Data.Size;
+        *GetReportOffset(pParser, pParser->Data.ReportID, (u_char)(pParser->Item & ITEM_MASK)) += pParser->Data.Size;
 
         /* Remove path last node */
         pParser->Data.Path.Size--;
@@ -256,17 +256,17 @@ int HIDParse(HIDParser* pParser, HIDData* pData)
       }
       case ITEM_REP_ID :
       {
-        pParser->Data.ReportID=(uchar)pParser->Value;
+        pParser->Data.ReportID=(u_char)pParser->Value;
         break;
       }
       case ITEM_REP_SIZE :
       {
-        pParser->Data.Size=(uchar)pParser->Value;
+        pParser->Data.Size=(u_char)pParser->Value;
         break;
       }
       case ITEM_REP_COUNT :
       {
-        pParser->ReportCount=(uchar)pParser->Value;
+        pParser->ReportCount=(u_char)pParser->Value;
         break;
       }
       case ITEM_UNIT_EXP :
@@ -348,7 +348,7 @@ int FindObject(HIDParser* pParser, HIDData* pData)
  * Use Value, Offset, Size and LogMax of pData.
  * Return response in Value.
  * -------------------------------------------------------------------------- */
-void GetValue(const uchar* Buf, HIDData* pData)
+void GetValue(const u_char* Buf, HIDData* pData)
 {
   int Bit=pData->Offset+8; /* First byte of report indicate report ID */
   int Weight=0;
@@ -365,7 +365,7 @@ void GetValue(const uchar* Buf, HIDData* pData)
     Bit++;
   }
 /*  if(pData->Value > pData->LogMax)
-    pData->Value=FormatValue(pData->Value, (uchar)((pData->Size-1)/8+1));
+    pData->Value=FormatValue(pData->Value, (u_char)((pData->Size-1)/8+1));
 */
   if (pData->Value > pData->LogMax)
     pData->Value |= ~pData->LogMax;
@@ -376,7 +376,7 @@ void GetValue(const uchar* Buf, HIDData* pData)
  * Set a data in a report stored in Buf. Use Value, Offset and Size of pData.
  * Return response in Buf.
  * -------------------------------------------------------------------------- */
-void SetValue(const HIDData* pData, uchar* Buf)
+void SetValue(const HIDData* pData, u_char* Buf)
 {
   int Bit=pData->Offset+8; /* First byte of report indicate report ID */
   int Weight=0;
