@@ -80,7 +80,7 @@ static const char *getpacket(int *we_know){
   ret=select(upsfd+1,  &readfds, NULL, NULL,&tv);
   if (!ret) {
 	s="Nothing received from UPS. Check cable conexion";
-	upslogx(LOG_ERR, s);
+	upslogx(LOG_ERR, "%s", s);
 	D(printf("%s\n",s);)
 	return NULL;
   }
@@ -118,7 +118,7 @@ static const char *getpacket(int *we_know){
      /* check validity of packet */
  if (!s) {
 	s="isbmex: no valid packet signature!";
-	upslogx(LOG_ERR, s);
+	upslogx(LOG_ERR, "%s", s);
 	D(printf("%s\n",s);)
 	*we_know=0;
 	return NULL;
