@@ -28,10 +28,9 @@
 #define _LIBHID_H
 
 #include <sys/types.h>
-
+#include "timehead.h"
 #include "hidtypes.h"
 
-/* typedef unsigned char  uchar; */
 /* use explicit booleans */
 #ifndef FALSE
 typedef enum ebool { FALSE, TRUE } bool;
@@ -39,6 +38,12 @@ typedef enum ebool { FALSE, TRUE } bool;
 typedef int bool;
 #endif
 
+/* Device open modes */
+#define MODE_OPEN 0
+#define MODE_REOPEN 1
+
+#define MAX_TS			2		/* validity period of a gotten report (1 sec) */
+
 /* ---------------------------------------------------------------------- */
 
 /*!
@@ -46,14 +51,14 @@ typedef int bool;
  */
 typedef struct
 {
-  char*     Name; /*!< HID Device name */
-  char*     Vendor; /*!< Device's Vendor Name */
-  u_int16_t VendorID; /*!< Device's Vendor ID */
-  char*     Product; /*!< Device's Product Name */
-  u_int16_t ProductID; /*!< Device's Product ID */
-  int       Application; /*!< match Usage for HIDOpenDevice(Usage)) */
-  char*     Serial; /* Product serial number */
-  int       fd; /* "internal" file descriptor */
+	char*     Name;		/*!< HID Device name */
+	char*     Vendor; /*!< Device's Vendor Name */
+	u_int16_t VendorID; /*!< Device's Vendor ID */
+	char*     Product; /*!< Device's Product Name */
+	u_int16_t ProductID; /*!< Device's Product ID */
+	int       Application; /*!< match Usage for HIDOpenDevice(Usage)) */
+	char*     Serial; /* Product serial number */
+	int       fd; /* "internal" file descriptor */
 } HIDDevice;
 
 /*!
@@ -61,15 +66,15 @@ typedef struct
  */
  typedef struct
 {
-	char*   Path; 	/*!< HID Object's fully qualified HID path */
-	long    Value; 	/*!< HID Object Value                               */
-	uchar   Attribute;	/*!< Report field attribute                         */
-	ulong   Unit; 		/*!< HID Unit                                       */
-	char    UnitExp;	/*!< Unit exponent                                  */
-	long    LogMin;	/*!< Logical Min                                    */
-	long    LogMax;	/*!< Logical Max                                    */
-	long    PhyMin;	/*!< Physical Min                                   */
-	long    PhyMax;	/*!< Physical Max                                   */
+	char*   Path;			/*!< HID Object's fully qualified HID path	*/
+	long    Value;		/*!< HID Object Value					*/
+	u_char   Attribute;	/*!< Report field attribute				*/
+	u_long   Unit; 		/*!< HID Unit							*/
+	char    UnitExp;		/*!< Unit exponent						*/
+	long    LogMin;		/*!< Logical Min							*/
+	long    LogMax;		/*!< Logical Max						*/
+	long    PhyMin;		/*!< Physical Min						*/
+	long    PhyMax;		/*!< Physical Max						*/
 } HIDItem;
 
 /*!
@@ -90,7 +95,7 @@ typedef struct
 /*
  * HIDOpenDevice
  * -------------------------------------------------------------------------- */
-HIDDevice *HIDOpenDevice(const char *port, MatchFlags *flg);
+HIDDevice *HIDOpenDevice(const char *port, MatchFlags *flg, int mode);
 
 /*
  * HIDGetItem
@@ -100,7 +105,7 @@ HIDItem *HIDGetItem(const char *ItemPath);
 /*
  * HIDGetItemValue
  * -------------------------------------------------------------------------- */
-float HIDGetItemValue(const char *path);
+float HIDGetItemValue(const char *path, float *Value);
 
 /*
  * HIDGetItemString
@@ -124,6 +129,7 @@ void HIDCloseDevice(HIDDevice *dev);
 
 
 
+void HIDDumpTree(HIDDevice *hd);
 int hid_lookup_usage(char *name);
 
 
