@@ -33,8 +33,13 @@
 #include "libhid.h"
 
 #include "hid-usb.h"
+#include "config.h" /* for LIBUSB_HAS_DETACH_KRNL_DRV flag */
+
+#include "common.h" /* for xmalloc prototype */
 
 usb_dev_handle *udev = NULL;
+struct usb_bus *bus;
+struct usb_device *dev;
 
 #define USB_TIMEOUT 5000
 
@@ -56,26 +61,31 @@ struct my_usb_hid_descriptor {
 };
 
 /* return report descriptor on success, NULL otherwise */
-int libusb_open(HIDDevice *curDevice, MatchFlags *flg, unsigned char *ReportDesc)
+/* mode: MODE_OPEN for the 1rst time, MODE_REOPEN to skip getting
+    report descriptor (the longer part) */
+int libusb_open(HIDDevice *curDevice, MatchFlags *flg, unsigned char *ReportDesc, int mode)
 {
-  struct usb_bus *bus;
-  struct usb_device *dev;
-  int found = 0;
-  struct my_usb_hid_descriptor *desc;
+	int found = 0;
+#if LIBUSB_HAS_DETACH_KRNL_DRV
+	int retries = 3;
+#endif
+	struct my_usb_hid_descriptor *desc;
 
-  int ret = -1, res; 
-  char buf[20];
+	int ret = -1, res; 
+	char buf[20];
+
+	/* libusb base init */
+/*	if (mode == MODE_OPEN) */
+		usb_init();
+	usb_find_busses();
+	usb_find_devices();
 
-  /* libusb base init */
-  usb_init();
-  usb_find_busses();
-  usb_find_devices();
 
   for (bus = usb_busses; bus && !found; bus = bus->next) {
     for (dev = bus->devices; dev && !found; dev = dev->next) {
       char string[256];
       
-      TRACE(2, "Opening new device");
+      TRACE(2, "\nOpening new device");
       udev = usb_open(dev);
       if (udev) {
 
@@ -84,6 +94,7 @@ int libusb_open(HIDDevice *curDevice, MatchFlags *flg, unsigned char *ReportDesc
 	  {
 	    TRACE(2, "Found %x, not matching VendorID", dev->descriptor.idVendor);
 	    usb_close(udev);
+	    udev = NULL;
 	    continue;
 	  }
 	else {
@@ -96,6 +107,7 @@ int libusb_open(HIDDevice *curDevice, MatchFlags *flg, unsigned char *ReportDesc
 	  {
 	    TRACE(2, "Found %x, not matching ProductID", dev->descriptor.idProduct);
 	    usb_close(udev);
+	    udev = NULL;
 	    continue;
 	  }
 	else {
@@ -104,9 +116,26 @@ int libusb_open(HIDDevice *curDevice, MatchFlags *flg, unsigned char *ReportDesc
 	}
 	
 	/* set default interface and claim it */
-	usb_set_altinterface(udev, 0);	
-	usb_claim_interface(udev, 0);
+	usb_set_altinterface(udev, 0);
 
+#if LIBUSB_HAS_DETACH_KRNL_DRV
+	/* this method requires libusb 0.1.8:
+	 * it force device claiming by unbinding
+	 * attached driver... From libhid */
+	while ((ret = usb_claim_interface(udev, 0)) != 0 && retries-- > 0) {
+	  
+	  TRACE(2, "failed to claim USB device, trying %d more time(s)...", retries);
+	  
+	  TRACE(2, "detaching kernel driver from USB device...");
+	  if (usb_detach_kernel_driver_np(udev, 0) < 0) {
+	    TRACE(2, "failed to detach kernel driver from USB device...");
+	  }
+	  
+	  TRACE(2, "trying again to claim USB device...");
+	}
+#else
+	usb_claim_interface(udev, 0);
+#endif
 	/* Get HID descriptor */
 	desc = (struct my_usb_hid_descriptor *)buf;
 	/* res = usb_get_descriptor(udev, USB_DT_HID, 0, buf, 0x9); */
@@ -115,7 +144,9 @@ int libusb_open(HIDDevice *curDevice, MatchFlags *flg, unsigned char *ReportDesc
 
 	if (res < 9) {
 	  if (res < 0) {
-	    TRACE(2, "Not a HID device: Unable to get HID descriptor (%d)", res);
+	    TRACE(2, "Unable to get HID descriptor (%s)", usb_strerror());
+	    usb_close(udev);
+	    udev = NULL;
 	    continue;
 	  }
 	  else
@@ -138,7 +169,12 @@ int libusb_open(HIDDevice *curDevice, MatchFlags *flg, unsigned char *ReportDesc
 	      curDevice->Name = curDevice->Vendor; /* FIXME: cat Vendor+Prod?! */
 	    }
           else
-            TRACE(2, "- Unable to fetch manufacturer string");
+			{
+			  TRACE(2, "- Unable to fetch manufacturer string");
+			  curDevice->Vendor = xmalloc(30);
+			  snprintf(curDevice->Vendor, 30, "Unknown vendor (0x%04x)",
+					   dev->descriptor.idVendor);
+            }
         }
 	
         if (dev->descriptor.iProduct) {
@@ -149,7 +185,12 @@ int libusb_open(HIDDevice *curDevice, MatchFlags *flg, unsigned char *ReportDesc
 	    curDevice->Product = strdup(string);
 	  }
           else
-            TRACE(2, "- Unable to fetch product string");
+			{
+			  TRACE(2, "-	 Unable to fetch product string");
+			  curDevice->Product = xmalloc(30);
+			  snprintf(curDevice->Product, 30, "Unknown product (0x%04x)",
+					   dev->descriptor.idProduct);
+            }
         }
 	
         if (dev->descriptor.iSerialNumber) {
@@ -167,33 +208,43 @@ int libusb_open(HIDDevice *curDevice, MatchFlags *flg, unsigned char *ReportDesc
       
       if (!dev->config) {
         TRACE(2, "  Couldn't retrieve descriptors");
+        usb_close(udev);
+        udev = NULL;
         continue;
       }
       
       /* usb_claim_interface(udev, 0); */
       
       /* usb_fetch_and_parse_descriptors(udev); => already done by usb_find_devices() */
-      
-      /* res = usb_get_descriptor(udev, USB_DT_REPORT, 0, bigbuf, desc->wDescriptorLength); */
-      res = usb_control_msg(udev, USB_ENDPOINT_IN+1, USB_REQ_GET_DESCRIPTOR,
-			    (USB_DT_REPORT << 8) + 0, 0, ReportDesc, 
-			    desc->wDescriptorLength, USB_TIMEOUT);
-      if (res < desc->wDescriptorLength) {
-	if (res < 0) {
-	  TRACE(2, "Unable to get Report descriptor (%d)", res);
+
+	/* Skip getting Report descriptor upon reconnexion */
+	if (mode == MODE_OPEN)
+	{      
+		/* res = usb_get_descriptor(udev, USB_DT_REPORT, 0, bigbuf, desc->wDescriptorLength); */
+		res = usb_control_msg(udev, USB_ENDPOINT_IN+1, USB_REQ_GET_DESCRIPTOR,
+								(USB_DT_REPORT << 8) + 0, 0, ReportDesc, 
+								desc->wDescriptorLength, USB_TIMEOUT);
+		if (res < desc->wDescriptorLength) {
+			if (res < 0)
+			{
+				TRACE(2, "Unable to get Report descriptor (%d)", res);
+			}
+			else
+			{
+				TRACE(2, "Report descriptor too short (expected %d, got %d)", 
+					desc->wDescriptorLength, res);
+			}
+			usb_close(udev);
+			udev = NULL;
+			continue;
+		}
+		else
+		{
+			TRACE(2, "Report descriptor retrieved (Reportlen = %i)", 
+				desc->wDescriptorLength);
+				ret = desc->wDescriptorLength;
+		}
 	}
-	else {
-	  TRACE(2, "Report descriptor too short (expected %d, got %d)", 
-		  desc->wDescriptorLength, res);
-	}
-	usb_close(udev);
-	continue;
-      }
-      else {
-	TRACE(2, "Report descriptor retrieved (Reportlen = %i)", 
-		desc->wDescriptorLength);
-	ret = desc->wDescriptorLength;
-      }
       
       /* we can break there, and be sure there's a HID device */
       found = 1;
@@ -213,21 +264,33 @@ int libusb_open(HIDDevice *curDevice, MatchFlags *flg, unsigned char *ReportDesc
 
 int libusb_get_report(int ReportId, unsigned char *raw_buf, int ReportSize )
 {
-  return usb_control_msg(udev, 
+	TRACE(4, "Entering libusb_get_report");
+	
+	if (udev != NULL)
+	{
+		return usb_control_msg(udev, 
 			 USB_ENDPOINT_IN + USB_TYPE_CLASS + USB_RECIP_INTERFACE,
 			 0x01, /* HID_REPORT_GET */
 			 ReportId+(0x03<<8), /* HID_REPORT_TYPE_FEATURE */
 			 0, raw_buf, ReportSize, USB_TIMEOUT);
+	}
+	else
+		return 0;
 }
 
 
 int libusb_set_report(int ReportId, unsigned char *raw_buf, int ReportSize )
 {
-  return usb_control_msg(udev, 
+	if (udev != NULL)
+	{
+		return usb_control_msg(udev, 
 			 USB_ENDPOINT_OUT + USB_TYPE_CLASS + USB_RECIP_INTERFACE,
 			 0x09, /* HID_REPORT_SET = 0x09*/
 			 ReportId+(0x03<<8), /* HID_REPORT_TYPE_FEATURE */
 			 0, raw_buf, ReportSize, USB_TIMEOUT);
+	}
+	else
+		return 0;
 }
 
 int libusb_get_string(int StringIdx, char *string)
@@ -263,6 +326,10 @@ int libusb_get_interrupt(unsigned char *buf, int bufsize, int timeout)
 
 void libusb_close(HIDDevice *curDevice)
 {
-  if (udev != NULL)
-    usb_close(udev);
+	if (udev != NULL)
+	{
+		usb_release_interface(udev, 0);
+		usb_close(udev);
+	}
+	udev = NULL;
 }
