@@ -22,6 +22,8 @@
 */
 
 #include "main.h"
+#include "serial.h"
+
 #include <sys/ioctl.h>
 
 #define	ML_ONBATTERY	0x55
@@ -60,8 +62,9 @@ void upsdrv_initinfo(void)
 /* normal idle loop - keep up with the current state of the UPS */
 void upsdrv_updateinfo(void)
 {
-	int	flags, ob, lb, ret;
+	int	flags, ret;
 	char	c;
+	unsigned int	ob, lb;
 	static	unsigned int	ob_state = 0, ob_last = 0, ob_ctr = 0;
 	static	unsigned int	lb_state = 0, lb_last = 0, lb_ctr = 0;
 
@@ -155,39 +158,6 @@ void upsdrv_updateinfo(void)
 	dstate_dataok();
 }
 
-/*  Open the serial port.  The upscommon routines aren't used because
-    they lose bits off the MCR required to make TX/RX work, and we
-    set up the port to make use of VMIN/VTIME.
-*/
-static void open_serial_ml(const char *port)
-{
-	int	flags;
-	struct termios tio;
-
-	signal(SIGALRM, openfail);
-	alarm(3);
-
-	if ((upsfd = open(port, O_RDWR | O_NONBLOCK)) == -1)
-		fatal("Unable to open %s", port);
-
-	alarm(0);
-
-	lockport(upsfd, port);
-
-	if (ioctl(upsfd, TIOCMGET, &flags))
-		fatal("get ioctl");
-	flags |= TIOCM_RTS;
-	if (ioctl(upsfd, TIOCMSET, &flags))
-		fatal("set ioctl");
-
-	tcgetattr(upsfd, &tio);
-	cfmakeraw(&tio);
-	tio.c_cflag |= CLOCAL;
-	tio.c_cc[VMIN] = 0;
-	tio.c_cc[VTIME] = 1;
-	tcsetattr(upsfd, TCSANOW, &tio);
-}
-
 void upsdrv_banner(void)
 {
 	printf("Network UPS Tools - Liebert MultiLink UPS driver 1.0 (%s)\n", 
@@ -208,9 +178,15 @@ void upsdrv_help(void)
 
 void upsdrv_initups(void)
 {
-	open_serial_ml(device_path);
+	int rts_bit = TIOCM_RTS;
+
+	upsfd = ser_open(device_path);
+
+	/* raise RTS */
+	ioctl(upsfd, TIOCMBIS, &rts_bit);
 }
 
 void upsdrv_cleanup(void)
 {
+	ser_close(upsfd, device_path);
 }
