@@ -30,15 +30,17 @@
  * 
  ********************************************************************/
 #include "main.h"
+#include "serial.h"
 
 #define UPSDELAY 3
 #define MAXTRIES 10
+#define UPS_PACE 100	/* 100 us between chars on write */
 
 #define Q1  1
 #define Q3  2
 
 #define DEBUG 1
-#define DRIVERVERSION "0.22"
+#define DRIVERVERSION "0.23"
 
 int     type;
 char    name[31];
@@ -53,7 +55,7 @@ char    firmware[6];
  * Returns NULL on reaching the end of the string.
  * 
  ********************************************************************/
-char *StringSplit( char *source, char *word, int maxlen )
+static char *StringSplit( char *source, char *word, int maxlen )
 {
     int     i;
     int     len;
@@ -83,7 +85,7 @@ char *StringSplit( char *source, char *word, int maxlen )
  * "word" has to be exacly the size of "source".
  * 
  ********************************************************************/
-void StringStrip( char *source, char *word )
+static void StringStrip( char *source, char *word )
 {
     int     wc=0;
     int     i;
@@ -111,7 +113,7 @@ void StringStrip( char *source, char *word )
  * command. Sets the INFO_STATUS value ( OL, OB, ... )
  * 
  ********************************************************************/
-void parseFlags( char *flags )
+static void parseFlags( char *flags )
 {
 	status_init();
 
@@ -153,7 +155,7 @@ void parseFlags( char *flags )
  * Also sets various values (IPFreq ... )
  * 
  ********************************************************************/
-void query1( char *buf )
+static void query1( char *buf )
 {
     #define WORDMAXLEN 255
     char    value[WORDMAXLEN];
@@ -227,7 +229,7 @@ void query1( char *buf )
  * Also sets various values (IPFreq ... )
  * 
  ********************************************************************/
-void query3( char *buf )
+static void query3( char *buf )
 {
     #define WORDMAXLEN 255
     char    value[WORDMAXLEN];
@@ -320,7 +322,7 @@ void query3( char *buf )
  * values of the firmware version and the UPS identification.
  * 
  ********************************************************************/
-void parseWH( char *buf )
+static void parseWH( char *buf )
 {
     strncpy( name, buf + 16, 30 );
     name[30] = '\0';
@@ -337,7 +339,7 @@ void parseWH( char *buf )
  * of the UPS.
  *
  ********************************************************************/
-void parseOldWH( char *buf )
+static void parseOldWH( char *buf )
 {
     strncpy( name, buf + 4, 12 );
     name[12] = '\0';
@@ -352,7 +354,7 @@ void parseOldWH( char *buf )
  * Function to fake a WhoAmI response of a UPS that returns NAK.
  * 
  ********************************************************************/
-void fakeWH( )
+static void fakeWH(void)
 {
     strcpy( name, "GenericUPS" );
     strcpy( firmware, "unkn" );
@@ -360,14 +362,14 @@ void fakeWH( )
         printf( "Name = %s, Firmware Version = %s\n", name, firmware );
 }
 
-int ups_ident( void )
+static int ups_ident( void )
 {
     char    buf[255];
     int     ret;
 
     /* Check presence of Q1 */
-    ret = upssend( "Q1\x0D" );
-    ret = upsrecv( buf, 250, '\x0D', "");
+    ret = ser_send_pace(upsfd, UPS_PACE, "%s", "Q1\x0D" );
+    ret = ser_get_line(upsfd, buf, sizeof(buf), '\r', "", 3, 0);
     ret = strlen( buf );
     if( ret != 46 ) 
     {
@@ -383,8 +385,8 @@ int ups_ident( void )
     }
 
     /* Check presence of Q3 */
-    ret = upssend( "Q3\x0D" );
-    ret = upsrecv( buf, 250, '\x0D', "");
+    ret = ser_send_pace(upsfd, UPS_PACE, "%s", "Q3\x0D" );
+    ret = ser_get_line(upsfd, buf, sizeof(buf), '\r', "", 3, 0);
     ret = strlen( buf );
     if( ret == 70 ) 
     {
@@ -394,8 +396,8 @@ int ups_ident( void )
     }
     
     /* Check presence of WH ( Who am I ) */
-    ret = upssend( "WH\x0D" );
-    ret = upsrecv( buf, 250, '\x0D', "");
+    ret = ser_send_pace(upsfd, UPS_PACE, "%s", "WH\x0D" );
+    ret = ser_get_line(upsfd, buf, sizeof(buf), '\r', "", 3, 0);
     ret = strlen( buf );
     if( ret == 112 )
     {
@@ -477,13 +479,13 @@ void upsdrv_updateinfo(void)
     /* Q3 found ? */
     if( type & Q3 )
     {
-        upssend( "Q3\x0D" );
+        ser_send_pace(upsfd, UPS_PACE, "%s", "Q3\x0D" );
         lenRSP = 70;
     }
     /* Q1 found ? */
     else if( type & Q1 )
     {
-        upssend( "Q1\x0D" );
+        ser_send_pace(upsfd, UPS_PACE, "%s", "Q1\x0D" );
         lenRSP = 46;
     }
     /* Should never be reached */
@@ -495,7 +497,7 @@ void upsdrv_updateinfo(void)
     sleep( UPSDELAY );
     
     buf[0] = '\0';
-    upsrecv( buf, 250, '\x0D', "\n");
+    ret = ser_get_line(upsfd, buf, sizeof(buf), '\r', "", 3, 0);
     ret = strlen( buf );
 
     if( ret != lenRSP ) 
@@ -534,7 +536,7 @@ void upsdrv_updateinfo(void)
 void upsdrv_shutdown(void)
 {
 	/* ups will come up within a minute if utility is restored */
-    upssend( "S.2R0001\x0D" );
+    ser_send_pace(upsfd, UPS_PACE, "%s", "S.2R0001\x0D" );
 }
 
 /********************************************************************
@@ -575,9 +577,9 @@ void upsdrv_initups(void)
     int     good  = 0;
     
 	/* setup serial port */
-    upssend_delay = 100; 
-	open_serial( device_path, B2400 );
-   
+    upsfd = ser_open(device_path);
+    ser_set_speed(upsfd, device_path, B2400);
+
     name[0] = '\0';
     firmware[0] = '\0';
 
@@ -599,7 +601,7 @@ void upsdrv_initups(void)
     if( ! good )
     {        
         printf( "No MASTERGUARD UPS found\n" );
-        exit( 1 );
+        exit(EXIT_FAILURE);
     }
        
     printf( "MASTERGUARD UPS found\n" );
@@ -607,8 +609,8 @@ void upsdrv_initups(void)
     /* Cancel Shutdown */
     if( testvar("CS") )
     {
-       upssend( "C\x0D" );
-       exit( 1 );
+       ser_send_pace(upsfd, UPS_PACE, "%s", "C\x0D" );
+       exit(EXIT_FAILURE);
     }
 }
 
@@ -624,4 +626,5 @@ void upsdrv_initups(void)
 
 void upsdrv_cleanup(void)
 {
+	ser_close(upsfd, device_path);
 }
