@@ -74,7 +74,7 @@ hid_desc_data_u    	hid_descriptor;
 device_desc_data_u 	device_descriptor;
 static HIDData   	hData;
 static HIDParser 	hParser;
-unsigned char 		raw_buf[4096];
+u_char 			raw_buf[4096];
 
 /* --------------------------------------------------------------- */
 /*                     Function prototypes                         */
@@ -82,7 +82,7 @@ unsigned char 		raw_buf[4096];
 
 float expo(int a, int b);
 void format_model_name(char *iProduct, char *iModel);
-extern long FormatValue(long Value, uchar Size);
+extern long FormatValue(long Value, u_char Size);
 
 /* --------------------------------------------------------------- */
 /*                    UPS Driver Functions                         */
@@ -97,6 +97,10 @@ void upsdrv_initinfo (void)
 	/* Get complete Model information */
 	shut_identify_ups ();
 
+	printf("Detected %s [%s] on %s\n", dstate_getinfo("ups.model"),
+		   dstate_getinfo("ups.serial"), device_path);
+
+
 	/* Device capabilities enumeration ----------------------------- */
 	for ( item = mge_info ; item->type != NULL ; item++ ) {
 		
@@ -106,10 +110,23 @@ void upsdrv_initinfo (void)
 		
 		/* Special case for handling server side variables */
 		if (item->shut_flags & SHUT_FLAG_ABSENT) {
-			dstate_setinfo(item->type, item->dfl);
-			dstate_setflags(item->type, item->flags);
-			/* disable reading now 
-			item->shut_flags &= ~SHUT_FLAG_OK;*/
+		  /* Check if exists (if necessary) before creation */
+		  if ((item->item_path != NULL) &&
+			  (hid_get_value(item->item_path) != 1 ) )
+			{
+			  continue;
+			}
+
+		  dstate_setinfo(item->type, "%s", item->dfl);
+		  dstate_setflags(item->type, item->flags);;
+		  
+		  /* Set max length for strings, if neede	d */
+		  if (item->flags & ST_FLAG_STRING)
+			dstate_setaux(item->type, item->length);
+
+		  /* disable reading now => needed?!
+			 item->shut_flags &= ~HU_FLAG_OK;*/
+
 		} else {
 			if (hid_get_value(item->item_path) != 0 ) {
 
@@ -346,7 +363,7 @@ int instcmd(const char *cmdname, const char *extra)
  *****************************************************************************/
 int shut_ups_start ()
 {
-	unsigned char c = SHUT_SYNC, r[1];
+	u_char c = SHUT_SYNC, r[1];
 	int try;
 	
 	upsdebugx (2, "entering shut_ups_start()\n");
@@ -415,15 +432,14 @@ int shut_identify_ups ()
 		else
 			format_model_name(model, NULL);
 
-		dstate_setinfo("ups.model", model);
-		upsdebugx (1, "Detected: %s", model);
+		dstate_setinfo("ups.model", "%s", model);
 	}
 		
 	/* Get strings iSerialNumber */
 	if (((retcode = shut_get_string(device_descriptor.dev_desc.iSerialNumber, string, 0x25)) > 0)
 		&& strcmp(string, "") && string[0] != '\t') {
 
-			dstate_setinfo("ups.serial", string);
+			dstate_setinfo("ups.serial", "%s", string);
 	}
 	else
 		dstate_setinfo("ups.serial", "unknown");
@@ -441,7 +457,7 @@ int shut_identify_ups ()
  *********************************************************************/
 int shut_wait_ack (void)
 {
-	unsigned char c[1];
+	u_char c[1];
 
 	c[0] = '\0';
 	
@@ -518,11 +534,11 @@ static int char_read (char *bytes, int size, int read_timeout)
  * returns 0 on success, -1 on error, -2 on timeout
  * 
  **********************************************************************/
-int serial_read (int read_timeout, unsigned char *readbuf)
+int serial_read (int read_timeout, u_char *readbuf)
 {
-	static unsigned char cache[512];
-	static unsigned char *cachep = cache;
-	static unsigned char *cachee = cache;
+	static u_char cache[512];
+	static u_char *cachep = cache;
+	static u_char *cachee = cache;
 	int recv;
 	*readbuf = '\0';
 	
@@ -561,10 +577,10 @@ int serial_read (int read_timeout, unsigned char *readbuf)
  * returns number of bytes written on success, -1 on error
  * 
  **********************************************************************/
-int serial_send (unsigned char *buf, int len)
+int serial_send (u_char *buf, int len)
 {
 	tcflush (upsfd, TCIFLUSH);
-	dump_hex ("sent", (unsigned char *)buf, len);
+	dump_hex ("sent", (u_char *)buf, len);
 	return write (upsfd, buf, len);
 }
 
@@ -624,10 +640,10 @@ void  shut_ups_status(void)
 }
 
 /* Calculate the SHUT checksum for the packet "buf" */
-uchar shut_checksum(const unsigned char *buf, int bufsize)
+u_char shut_checksum(const u_char *buf, int bufsize)
 {
 	int i;
-	unsigned char chk=0;
+	u_char chk=0;
 	
 	for(i=0; i<bufsize; i++)
 		chk^=buf[i];
@@ -635,14 +651,14 @@ uchar shut_checksum(const unsigned char *buf, int bufsize)
 }
 
 /* Send token (1 char packet) "token" */
-int shut_token_send(unsigned char token)
+int shut_token_send(u_char token)
 {
-	unsigned char Buf[1];
+	u_char Buf[1];
 	Buf[0]=token;
 	return serial_send (Buf, 1);
 }
 
-int shut_packet_send (hid_data_u *hdata, int datalen, unsigned char token)
+int shut_packet_send (hid_data_u *hdata, int datalen, u_char token)
 {
 	shut_packet_t SHUTRequest;
 	shut_data_u   sdata;
@@ -697,14 +713,14 @@ int shut_packet_send (hid_data_u *hdata, int datalen, unsigned char token)
 	return (datalen==0);
 }
 
-int shut_packet_recv (unsigned char *Buf, int datalen)
+int shut_packet_recv (u_char *Buf, int datalen)
 {
-	unsigned char   Start[2];
-	unsigned char   Frame[8];
-	unsigned char   Chk[1];
-	unsigned short  Size=8;
-	unsigned short  Pos=0;
-	unsigned char   Retry=0;
+	u_char   Start[2];
+	u_char   Frame[8];
+	u_char   Chk[1];
+	u_short  Size=8;
+	u_short  Pos=0;
+	u_char   Retry=0;
 	int recv;
 	shut_data_u   sdata;
 
@@ -763,7 +779,7 @@ int shut_packet_recv (unsigned char *Buf, int datalen)
 					}
 					else
 					{
-						upsdebugx (4, "shut_checksum: %02x => NOK", Chk);
+						upsdebugx (4, "shut_checksum: %02x => NOK", Chk[0]);
 						shut_token_send(SHUT_NOK);
 						Retry++;
 					}
@@ -783,7 +799,7 @@ int shut_packet_recv (unsigned char *Buf, int datalen)
  *********************************************************************/
 
 /**********************************************************************
- * shut_get_descriptor(int desctype, unsigned char *pkt)
+ * shut_get_descriptor(int desctype, u_char *pkt)
  * 
  * get descriptor specified by DescType and return it in Buf
  *
@@ -793,7 +809,7 @@ int shut_packet_recv (unsigned char *Buf, int datalen)
  * return 0 on success, -1 on failure, -2 on NACK
  *
  *********************************************************************/
-int shut_get_descriptor(int desctype, unsigned char *pkt, int reportlen)
+int shut_get_descriptor(int desctype, u_char *pkt, int reportlen)
 {
 	hid_packet_t HIDRequest;
 	hid_data_u   data;
@@ -827,7 +843,7 @@ int shut_get_descriptor(int desctype, unsigned char *pkt, int reportlen)
 }
 
 /**********************************************************************
- * shut_get_string(int index, unsigned char *pkt, int reportlen)
+ * shut_get_string(int index, u_char *pkt, int reportlen)
  * 
  * get descriptor specified by DescType and return it in Buf
  *
@@ -843,7 +859,7 @@ int shut_get_string(int strindex, char *string, int stringlen)
 	hid_packet_t HIDRequest;
 	hid_data_u   data;
 	int retcode;
-	unsigned char buf[MAX_STRING];
+	u_char buf[MAX_STRING];
 	
 	upsdebugx (3, "entering shut_get_string(%02x)", strindex);
 	
@@ -874,7 +890,7 @@ int shut_get_string(int strindex, char *string, int stringlen)
 }
 
 /**********************************************************************
- * shut_get_report(int id, unsigned char *pkt, int reportlen)
+ * shut_get_report(int id, u_char *pkt, int reportlen)
  * 
  * get report specified by id and return it in pkt
  *
@@ -885,7 +901,7 @@ int shut_get_string(int strindex, char *string, int stringlen)
  * return report size on success, -1 on failure, -2 on NACK
  *
  *********************************************************************/
-int shut_get_report(int id, unsigned char *pkt, int reportlen)
+int shut_get_report(int id, u_char *pkt, int reportlen)
 {
 	hid_packet_t HIDRequest;
 	hid_data_u   data;
@@ -918,7 +934,7 @@ int shut_get_report(int id, unsigned char *pkt, int reportlen)
 }
 
 /**********************************************************************
- * shut_set_report(int id, unsigned char *pkt, int reportlen)
+ * shut_set_report(int id, u_char *pkt, int reportlen)
  * 
  * set report specified by id using pkt as value
  *
@@ -929,7 +945,7 @@ int shut_get_report(int id, unsigned char *pkt, int reportlen)
  * return string size on success, -1 on failure, -2 on NACK
  *
  *********************************************************************/
-int shut_set_report(int id, unsigned char *pkt, int reportlen)
+int shut_set_report(int id, u_char *pkt, int reportlen)
 {
 	hid_packet_t HIDRequest;
 	hid_data_u   data;
@@ -1137,9 +1153,9 @@ int hid_get_value(const char *item_path)
 		/* Get info on object (reportID, offset and size) */
 		if (FindObject(&hParser,&hData) == 1) {
 			if (shut_get_report(hData.ReportID, raw_buf, MAX_REPORT_SIZE) > 0) {
-				GetValue((const unsigned char *) raw_buf, &hData);
+				GetValue((const u_char *) raw_buf, &hData);
 				dump_hex("Object's report", raw_buf, 10);
-				upsdebugx(3, "Value = %d", hData.Value);
+				upsdebugx(3, "Value = %ld", hData.Value);
 				return 1;
 			}
 			else
@@ -1155,7 +1171,8 @@ int hid_get_value(const char *item_path)
 		return 0;
 	}
 
-	return 0;
+	/* all went fine */
+	return 1;
 }
 
   /* 
@@ -1176,13 +1193,13 @@ int hid_get_value(const char *item_path)
 
 #define NIBBLE(_i)    (((_i) < 10) ? '0' + (_i) : 'A' + (_i) - 10)
 
-void dump_hex (const char *msg, const unsigned char *buf, int len)
+void dump_hex (const char *msg, const u_char *buf, int len)
 {
 	int i;
 	int nlocal;
-	const unsigned char *pc;
+	const u_char *pc;
 	char *out;
-	const unsigned char *start;
+	const u_char *start;
 	char c;
 	char line[100];
 
@@ -1220,7 +1237,7 @@ void dump_hex (const char *msg, const unsigned char *buf, int len)
  * Byte2: String descriptor type (always 0x03)
  * Byte3 to byteN: UNICODE string (in US: xx 00 for a letter)
  */
-void make_string(unsigned char *buf, int datalen, char *string)
+void make_string(u_char *buf, int datalen, char *string)
 {
 	int i,		/* Skip size and type */ 
 		j=0;
@@ -1306,6 +1323,18 @@ void format_model_name(char *iProduct, char *iModel)
 
 		return;
 	}
+
+	/* NOVA model range */
+	if(!strncmp(iProduct, "NOVA", 4)) {
+		/* This gives 600 for NOVA 600 AVR... */
+		if(hid_get_value("UPS.Flow.[4].ConfigApparentPower") != 0 )
+			sprintf(iProduct, "NOVA %ld AVR", hData.Value);
+		else
+			sprintf(iProduct, "NOVA AVR");
+
+		return;
+	}
+
 }
 
 /* set r/w INFO_ element to a value. */
@@ -1335,7 +1364,7 @@ int hid_set_value(const char *varname, const char *val)
 	/* handle server side variable */
 	if (shut_info_p->shut_flags & SHUT_FLAG_ABSENT) {
 		upsdebugx(2, "hid_ups_set: setting server side variable %s", varname);
-		dstate_setinfo(shut_info_p->type, val);
+		dstate_setinfo(shut_info_p->type, "%s", val);
 		return STAT_SET_HANDLED;
 	} else {
 		/* SHUT_FLAG_ABSENT is the only case of HID Path == NULL */
@@ -1363,7 +1392,7 @@ int hid_set_value(const char *varname, const char *val)
 		if (FindObject(&hParser,&hData) == 1) {
 			replen = shut_get_report(hData.ReportID, raw_buf, MAX_REPORT_SIZE);
 			
-			GetValue((const unsigned char *) raw_buf, &hData);
+			GetValue((const u_char *) raw_buf, &hData);
 			
 			/* Test if Item is settable */
 			if (hData.Attribute != ATTR_DATA_CST) {
@@ -1374,7 +1403,7 @@ int hid_set_value(const char *varname, const char *val)
 				
 				/* check if set succeed ! => disabled for now
 				if (shut_get_report(hData.ReportID, raw_buf, MAX_REPORT_SIZE) > 0) {
-					GetValue((const unsigned char *) raw_buf, &hData);
+					GetValue((const u_char *) raw_buf, &hData);
 					upsdebugx(3, "Value = %d", hData.Value);
 				
 					if (hData.Value != atol(val))
@@ -1405,6 +1434,6 @@ mge_info_item *shut_find_info(const char *varname)
 		if (!strcasecmp(shut_info_p->type, varname))
 			return shut_info_p;
 		
-	fatalx("shut_find_info: unknown info type: 0x%x", varname);
+	fatalx("shut_find_info: unknown info type: %s", varname);
 	return NULL;
 }
