@@ -25,9 +25,9 @@
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
 
-#include <time.h>
 #include <ctype.h>
 #include <sys/ioctl.h>
+#include "timehead.h"
 #include "main.h"
 #include "serial.h"
 #include "mge-utalk.h"
@@ -37,7 +37,7 @@
 /* --------------------------------------------------------------- */
 
 #define DRIVER_NAME    "MGE UPS SYSTEMS/U-Talk driver"
-#define DRIVER_VERSION "0.80.3"
+#define DRIVER_VERSION "0.81.0"
 
 /* delay after sending each char to UPS (in MICROSECONDS) */
 #define MGE_CHAR_DELAY 0
@@ -127,6 +127,7 @@ void upsdrv_initups(void)
 {
 	char buf[BUFFLEN];
 	int RTS = TIOCM_RTS;
+	int  bytes_rcvd;
 	
 	upsfd = ser_open(device_path);
 	ser_set_speed(upsfd, device_path, B2400);
@@ -148,21 +149,34 @@ void upsdrv_initups(void)
 	ioctl(upsfd, TIOCMBIC, &RTS);
 	enable_ups_comm();
 
-	/* set values given on the command line */
-	mge_command(buf, sizeof(buf), "Bl %d",  mge_ups.LowBatt);
-	if(strcmp(buf, "OK"))
-		upsdebugx(1, "UPS response to %d%% Low Batt Level was %s",
-			mge_ups.LowBatt, buf);
-	
-	mge_command(buf, sizeof(buf), "Sm %d",  mge_ups.OnDelay);
-	if(strcmp(buf, "OK"))
-		upsdebugx(1, "UPS response to %d min ON delay was %s",
-			mge_ups.OnDelay, buf);
-	
-	mge_command(buf, sizeof(buf), "Sn %d",  mge_ups.OffDelay);
-	if(strcmp(buf, "OK"))
-		upsdebugx(1, "UPS response to %d min OFF delay was %s",
-			mge_ups.OffDelay, buf);
+	/* Get and set values (if exists) given on the command line */
+	bytes_rcvd = mge_command(buf, sizeof(buf), "Bl ?");
+	if(bytes_rcvd > 0 && buf[0] != '?') {
+		mge_command(buf, sizeof(buf), "Bl %d",  mge_ups.LowBatt);
+		if(strcmp(buf, "OK"))
+			upsdebugx(1, "UPS response to %d%% Low Batt Level was %s",
+				mge_ups.LowBatt, buf);
+	} else
+		upsdebugx(1, "initups: LowBatt unavailable");
+
+	bytes_rcvd = mge_command(buf, sizeof(buf), "Sm ?");
+	if(bytes_rcvd > 0 && buf[0] != '?') {
+		mge_command(buf, sizeof(buf), "Sm %d",  mge_ups.OnDelay);
+		if(strcmp(buf, "OK"))
+			upsdebugx(1, "UPS response to %d min ON delay was %s",
+				mge_ups.OnDelay, buf);
+	} else
+		upsdebugx(1, "initups: OnDelay unavailable");
+
+	bytes_rcvd = mge_command(buf, sizeof(buf), "Sn ?");
+	if(bytes_rcvd > 0 && buf[0] != '?') {
+		mge_command(buf, sizeof(buf), "Sn %d",  mge_ups.OffDelay);
+		if(strcmp(buf, "OK"))
+			upsdebugx(1, "UPS response to %d min OFF delay was %s",
+				mge_ups.OffDelay, buf);
+	} else
+		upsdebugx(1, "initups: OffDelay unavailable");
+
 }
 
 /* --------------------------------------------------------------- */
@@ -181,7 +195,7 @@ void upsdrv_initinfo(void)
 	
 	/* manufacturer -------------------------------------------- */
 	dstate_setinfo("ups.mfr", "MGE UPS SYSTEMS");
-	dstate_setinfo("driver.version.internal", DRIVER_VERSION);
+	dstate_setinfo("driver.version.internal", "%s", DRIVER_VERSION);
 	
 	/* loop until we have at status */
 	tries = 0;
@@ -257,11 +271,17 @@ void upsdrv_initinfo(void)
 			item->ok = TRUE;
 			extract_info(buf, item, infostr, sizeof(infostr));
 			dstate_setinfo(item->type, "%s", infostr);
+			dstate_setflags(item->type, item->flags);
 			upsdebugx(1, "initinfo: %s == >%s<", item->type, infostr);
+
+			/* Set max length for strings */
+			if (item->flags & ST_FLAG_STRING)
+				dstate_setaux(item->type, item->length);
 		}
 	} /* for item */
 
 	/* commands ----------------------------------------------- */
+	/* FIXME: check if available before adding! */
 	dstate_addcmd("load.off");
 	dstate_addcmd("load.on");
 	dstate_addcmd("shutdown.return");
@@ -476,7 +496,7 @@ int setvar(const char *varname, const char *val)
     
 		/* Execute command */
 		mge_command(temp, sizeof(temp), cmd);
-		upsdebugx(1, "setvar: UPS response to Set %s to %s was %s", varname, val, temp);
+		upslogx(LOG_INFO, "setvar: UPS response to Set %s to %s was %s", varname, val, temp);
 	} else
 		upsdebugx(1, "setvar: Variable %s not supported by UPS", varname);
 	
@@ -693,7 +713,7 @@ static int mge_command(char *reply, int replylen, const char *fmt, ...)
 	
 	/* send command */
 	for (p = command; *p; p++) {
-		if ( isprint(*p) )
+		if ( isprint(*p & 0xFF) )
 			upsdebugx(4, "mge_command: sending [%c]", *p);
 		else
 			upsdebugx(4, "mge_command: sending [%02X]", *p);
@@ -708,7 +728,7 @@ static int mge_command(char *reply, int replylen, const char *fmt, ...)
 	/* send terminating string */
 	if (MGE_COMMAND_ENDCHAR) {
 		for (p = MGE_COMMAND_ENDCHAR; *p; p++) {
-			if ( isprint(*p) )
+			if ( isprint(*p & 0xFF) )
 				upsdebugx(4, "mge_command: sending [%c]", *p);
 			else
 				upsdebugx(4, "mge_command: sending [%02X]", *p);
