@@ -2,7 +2,7 @@
 
    Type Declarations and Constant Definitions for MGE UTalk Driver
 
-   Copyright (C) 2002 - 2003
+   Copyright (C) 2002 - 2004
    
    	Hans Ekkehard Plesser <hans.plesser@itf.nlh.no>
 	Arnaud Quette <arnaud.quette@free.fr>
@@ -83,11 +83,11 @@ typedef enum ebool { FALSE=0, TRUE } bool;
    information to INFO structure.
 */
 typedef struct {
-	char *type;                /* INFO_* element                        */
+	const char *type;          /* INFO_* element                        */
 	int   flags;               /* INFO-element flags to set in addinfo  */
 	int   length;              /* INFO-element length of strings        */  
-	char  cmd[32];             /* UPS command string to requets element */
-	char  fmt[32];             /* printf format string for INFO entry   */
+	const char  cmd[32];       /* UPS command string to requets element */
+	const char  fmt[32];       /* printf format string for INFO entry   */
 	units unit;                /* unit of measurement, or NONE          */
 	bool  ok;                  /* flag indicating if item is available  */
 } mge_info_item;
@@ -105,14 +105,14 @@ static mge_info_item mge_info[] = {
 	{ "battery.charge", 0, 0, "Bl", "%05.1f", NONE, TRUE },
 	{ "battery.runtime", 0, 0, "Bn", "%05d", NONE,	TRUE },
 	{ "battery.voltage",  0, 0, "Bv", "%05.1f", VOLT, TRUE },
-	{ "battery.charge.low", ST_FLAG_RW | FLAG_STRING, 2, "Bl ?", "%02d", NONE, TRUE },
+	{ "battery.charge.low", ST_FLAG_RW | ST_FLAG_STRING, 2, "Bl ?", "%02d", NONE, TRUE },
 	{ "battery.voltage.nominal", 0, 0, "Bv ?", "%05.1f", VOLT,	 TRUE },
 	/* UPS page */
 	{ "ups.temperature", 0, 0, "St", "%05.1f", DEGCELS, TRUE },
 	{ "ups.load", 0, 0, "Ll", "%05.1f", NONE, TRUE },
-	{ "ups.delay.start", ST_FLAG_RW | FLAG_STRING, 5, "Sm ?", "%03d", NONE, TRUE },
-	{ "ups.delay.shutdown",  ST_FLAG_RW | FLAG_STRING, 5, "Sn ?", "%03d", NONE, TRUE },
-	{ "ups.test.interval", ST_FLAG_RW | FLAG_STRING, 5, "Bp ?", "%03d", NONE, TRUE },
+	{ "ups.delay.start", ST_FLAG_RW | ST_FLAG_STRING, 5, "Sm ?", "%03d", NONE, TRUE },
+	{ "ups.delay.shutdown",  ST_FLAG_RW | ST_FLAG_STRING, 5, "Sn ?", "%03d", NONE, TRUE },
+	{ "ups.test.interval", ST_FLAG_RW | ST_FLAG_STRING, 5, "Bp ?", "%03d", NONE, TRUE },
 	/* Output page */
 	{ "output.voltage", 0, 0, "Lv", "%05.1f", VOLT, TRUE },
 	{ "output.current", 0, 0, "Lc", "%05.1f", AMPERE, TRUE },
@@ -120,13 +120,13 @@ static mge_info_item mge_info[] = {
 	{ "input.voltage", 0, 0, "Uv", "%05.1f", VOLT, TRUE },
 	{ "input.frequency", 0, 0, "Uf", "%05.2f", HERTZ, TRUE },
 	/* same as LOBOOSTXFER */
-	{ "input.transfer.low", ST_FLAG_RW | FLAG_STRING, 5, "Ee ?", "%05.1f", VOLT, TRUE },
-	{ "input.transfer.boost.low", ST_FLAG_RW | FLAG_STRING, 5, "Ee ?", "%05.1f", VOLT, TRUE },
-	{ "input.transfer.boost.high", ST_FLAG_RW | FLAG_STRING, 5, "Eo ?", "%05.1f", VOLT, TRUE },
-	{ "input.transfer.trim.low", ST_FLAG_RW | FLAG_STRING, 5, "Ea ?", "%05.1f", VOLT, TRUE },
+	{ "input.transfer.low", ST_FLAG_RW | ST_FLAG_STRING, 5, "Ee ?", "%05.1f", VOLT, TRUE },
+	{ "input.transfer.boost.low", ST_FLAG_RW | ST_FLAG_STRING, 5, "Ee ?", "%05.1f", VOLT, TRUE },
+	{ "input.transfer.boost.high", ST_FLAG_RW | ST_FLAG_STRING, 5, "Eo ?", "%05.1f", VOLT, TRUE },
+	{ "input.transfer.trim.low", ST_FLAG_RW | ST_FLAG_STRING, 5, "Ea ?", "%05.1f", VOLT, TRUE },
 	/* same as HITRIMXFER */
-	{ "input.transfer.high", ST_FLAG_RW | FLAG_STRING, 5, "Eu ?", "%05.1f", VOLT, TRUE },
-	{ "input.transfer.trim.high", ST_FLAG_RW | FLAG_STRING, 5, "Eu ?", "%05.1f", VOLT, TRUE },
+	{ "input.transfer.high", ST_FLAG_RW | ST_FLAG_STRING, 5, "Eu ?", "%05.1f", VOLT, TRUE },
+	{ "input.transfer.trim.high", ST_FLAG_RW | ST_FLAG_STRING, 5, "Eu ?", "%05.1f", VOLT, TRUE },
 	/* terminating element */
 	{ NULL, 0, 0, "\0",	"\0", NONE, FALSE } 
 };
