@@ -34,7 +34,9 @@ static hid_info_t *hid_ups;
 static HIDDevice *hd;
 static int offdelay = DEFAULT_OFFDELAY;
 static int ondelay = DEFAULT_ONDELAY;
-
+MatchFlags flg;
+static bool data_has_changed = FALSE; /* for SEMI_STATIC data polling */
+  
 /* support functions */
 static int setvar(const char *varname, const char *val);
 static hid_info_t *find_info(const char *varname);
@@ -93,6 +95,8 @@ static int instcmd(const char *cmdname, const char *extradata)
   if (HIDSetItemValue(hidups_item->hidpath, atol(hidups_item->dfl))) {
 
     upsdebugx(3, "SUCCEED\n");
+    /* Set the status so that SEMI_STATIC vars are polled */
+    data_has_changed = TRUE;
     return STAT_INSTCMD_HANDLED;
   }
   else
@@ -128,7 +132,7 @@ static int setvar(const char *varname, const char *val)
   /* handle server side variable */
   if (hidups_item->hidflags & HU_FLAG_ABSENT) {
     upsdebugx(2, "setvar: setting server side variable %s\n", varname);
-    dstate_setinfo(hidups_item->info_type, val);
+    dstate_setinfo(hidups_item->info_type, "%s", val);
     return STAT_SET_HANDLED;
   } else {
     /* SHUT_FLAG_ABSENT is the only case of HID Path == NULL */
@@ -145,6 +149,8 @@ static int setvar(const char *varname, const char *val)
     upsdebugx(3, "SUCCEED\n");
     /* Delay a bit not to flood the device */
     sleep(1);
+    /* Set the status so that SEMI_STATIC vars are polled */
+    data_has_changed = TRUE;
     return STAT_SET_HANDLED;
   }
   else
@@ -182,154 +188,200 @@ void upsdrv_banner(void)
 /* TODO: merge {init,update}info in hidups_walk() */
 void upsdrv_updateinfo(void) 
 {
-  hid_info_t *item;
-  float value;
-  char *nutvalue;
+	hid_info_t *item;
+	float value;
+	char *nutvalue;
+	int tries=0, retcode;
 
-  upsdebugx(1, "Updating...\n");
+	upsdebugx(1, "\n=>Updating...");
 
-  /* clear status buffer before begining */
-  status_init();
+	/* clear status buffer before begining */
+	status_init();
 
-  /* Process pending events (HID notifications on Interrupt pipe) */
-  /* TODO: process "HIDItem HIDGetNextEvent(HIDDevice *dev);" */
+	/* Process pending events (HID notifications on Interrupt pipe) */
+	/* TODO: process "HIDItem HIDGetNextEvent(HIDDevice *dev);" */
 
-  /* Device data walk ----------------------------- */
-  for ( item = hid_ups ; item->info_type != NULL ; item++ ) {
+	/* Device data walk ----------------------------- */
+	for ( item = hid_ups ; item->info_type != NULL ; item++ )
+	{
+		/* These doesn't need polling after initinfo() */
+		if ((item->hidflags & HU_FLAG_ABSENT)
+			|| (item->hidflags & HU_TYPE_CMD)
+			|| (item->hidflags & HU_FLAG_STATIC)
+			/* These need to be polled after user changes (setvar / instcmd) */
+			|| ( (item->hidflags & HU_FLAG_SEMI_STATIC) && (data_has_changed == FALSE) ) )
+				continue;
 
-    if ((item->hidflags & HU_FLAG_ABSENT)
-	|| (item->hidflags & HU_TYPE_CMD))
-      continue;
-    
-    if (item->hidflags & HU_FLAG_OK) {
-      
-      /* TODO: 3 tryes before giving up (needed when OnBattery!) */
-      if ((value = HIDGetItemValue(item->hidpath)) != -2 ) {
+		if ( (item->hidflags & HU_FLAG_SEMI_STATIC) && (data_has_changed == TRUE) )
+			upsdebugx(2, "%s => HU_FLAG_SEMI_STATIC", item->hidpath);
 
-	/* deal with status items */
-	if (!strncmp(item->info_type, "ups.status", 10)) {
-	  
-	  nutvalue = hu_find_infoval(item->hid2info, (long)value);
-	  if (nutvalue != NULL)	  
-	    status_set(nutvalue);
+		if (item->hidflags & HU_FLAG_OK)
+		{
+			tries = 0;
+			value = -2;
 
-	} else { /* standard items */
-	  /* need lookup'ed translation */
-	  if (item->hid2info != NULL) {
-	    nutvalue = hu_find_infoval(item->hid2info, (long)value);
-	    if (nutvalue != NULL)
-	      dstate_setinfo(item->info_type, item->dfl, nutvalue);
-	  }
-	  else
-	    dstate_setinfo(item->info_type, item->dfl, value);
+			/* TODO: 3 tryes before giving up (needed when OnBattery!) */
+			while ( tries < MAX_TRY )
+			{
+				tries++;
+				retcode = HIDGetItemValue(item->hidpath, &value);
 
-	  dstate_dataok(); /* atomic "commit" call */
+				/* Did we get something */
+				if (retcode == 1 ) /* Yes */
+				{
+					tries = MAX_TRY;
+					upsdebugx(2, "%s = %f", item->hidpath, value);
+
+					/* deal with status items */
+					if (!strncmp(item->info_type, "ups.status", 10)) {
+
+						nutvalue = hu_find_infoval(item->hid2info, (long)value);
+						if (nutvalue != NULL)	  
+							status_set(nutvalue);
+
+					} else { /* standard items */
+						/* need lookup'ed translation */
+						if (item->hid2info != NULL) {
+							nutvalue = hu_find_infoval(item->hid2info, (long)value);
+							if (nutvalue != NULL)
+								dstate_setinfo(item->info_type, item->dfl, nutvalue);
+						}
+						else
+							dstate_setinfo(item->info_type, item->dfl, value);
+
+						dstate_dataok(); /* atomic "commit" call */
+					}
+				} else {
+					upsdebugx(2, "Can't get %s (retcode = %i)", item->hidpath, retcode);
+					if ( tries == (MAX_TRY -1) )
+						dstate_datastale();
+					/* Reserved values: -1/-10 for nul delay, -2 can't get value */
+					/* device has been disconnected, try to reconnect */
+					/*if ( (retcode != -1) && (retcode != -EPIPE) )
+					{
+						HIDCloseDevice(NULL);
+						sleep(3);
+						hd = HIDOpenDevice(device_path, &flg, MODE_REOPEN);
+					} */
+				}
+			} 
+		}
 	}
-      } else {
-	dstate_datastale();
-      }
-    }
-  }
-  /* Commit the status buffer */
-  status_commit();
+	/* Commit the status buffer */
+	status_commit();
+
+	/* Reset SEMI_STATIC flag */
+	data_has_changed = FALSE;
 }
 
 void upsdrv_initinfo(void)
 {
-  hid_info_t *item;
-  float value;
-  char *nutvalue;
+	hid_info_t *item;
+	float value;
+	char *nutvalue;
+	int retcode;
 
-  /* identify unit: fill ups.{mfr, model, serial} */
-  dstate_setinfo("ups.mfr", hd->Vendor);
-  dstate_setinfo("ups.model", format_model_name(hd->Product, NULL));
-  dstate_setinfo("ups.serial", (hd->Serial != NULL)?hd->Serial:"unknown");
+	/* identify unit: fill ups.{mfr, model, serial} */
+	dstate_setinfo("ups.mfr", "%s", hd->Vendor);
+	dstate_setinfo("ups.model", "%s", format_model_name(hd->Product, NULL));
+	dstate_setinfo("ups.serial", "%s", 
+		(hd->Serial != NULL)?hd->Serial:"unknown");
 
-  /* TODO: load lookup file (WARNING: should be in initups()
-     because of -k segfault (=> not calling upsdrv_initinfo())
-  */
+	/* TODO: load lookup file (WARNING: should be in initups()
+	because of -k segfault (=> not calling upsdrv_initinfo())
+	*/
 
-  /* clear status buffer before begining */
-  status_init();
+	/* clear status buffer before begining */
+	status_init();
 
-  /* Device capabilities enumeration ----------------------------- */
-  for ( item = hid_ups ; item->info_type != NULL ; item++ ) {
+	/* Device capabilities enumeration ----------------------------- */
+	for ( item = hid_ups ; item->info_type != NULL ; item++ )
+	{
+		/* Avoid redundancy when multiple defines (RO/RW)
+		* Not applicable to "ups.status" items!
+		*/
 
-    /* Avoid redundancy when multiple defines (RO/RW)
-     * Not applicable to "ups.status" items!
-     */
-    if ((dstate_getinfo(item->info_type) != NULL)
-	&& (strncmp(item->info_type, "ups.status", 10))) { 
-      item->hidflags &= ~HU_FLAG_OK;
-      continue;
-    }
-	
-    /* Special case for handling instant commands */
-    if (item->hidflags & HU_TYPE_CMD) {
-      /* Check actual availability */
-      if (HIDGetItemValue(item->hidpath) != -2 ) {
-	dstate_addcmd(item->info_type);
-      }
-      continue;
-    }
+		if ((dstate_getinfo(item->info_type) != NULL)
+			&& (strncmp(item->info_type, "ups.status", 10)))
+		{
+			item->hidflags &= ~HU_FLAG_OK;
+			continue;
+		}
 
-    /* Special case for handling server side variables */
-    if (item->hidflags & HU_FLAG_ABSENT) {
-      dstate_setinfo(item->info_type, item->dfl);
-      dstate_setflags(item->info_type, item->info_flags);
-      /* disable reading now => needed?!
-	 item->shut_flags &= ~HU_FLAG_OK;*/
-    } else {
-      /* TODO: 3 tryes before giving up (needed when OnBattery!) */
-      if ((value = HIDGetItemValue(item->hidpath)) != -2 ) {
-	
-	item->hidflags &= HU_FLAG_OK;
+		/* Special case for handling instant commands */
+		if (item->hidflags & HU_TYPE_CMD)
+		{
+			/* Check actual availability */
+			if (HIDGetItemValue(item->hidpath, &value) == 1 )
+			{
+				dstate_addcmd(item->info_type);
+			}
+			continue;
+		}
 
-	/* deal with status items */
-	if (!strncmp(item->info_type, "ups.status", 10)) {
-	  nutvalue = hu_find_infoval(item->hid2info, (long)value);
-	  if (nutvalue != NULL)
-	    status_set(nutvalue);
+		/* Special case for handling server side variables */
+		if (item->hidflags & HU_FLAG_ABSENT)
+		{
+			dstate_setinfo(item->info_type, "%s", item->dfl);
+			dstate_setflags(item->info_type, item->info_flags);
 
-	} else { /* standard items */
-	  /* need lookup'ed translation */
-	  if (item->hid2info != NULL) {
-	    nutvalue = hu_find_infoval(item->hid2info, (long)value);
-	    if (nutvalue != NULL)
-	      dstate_setinfo(item->info_type, item->dfl, nutvalue);
-	  }
-	  else
-	    dstate_setinfo(item->info_type, item->dfl, value);
+			/* disable reading now => needed?!
+			item->shut_flags &= ~HU_FLAG_OK;*/
+		}
+		else
+		{
+			/* TODO: 3 tryes before giving up (needed when OnBattery!) */
+			if ((retcode = HIDGetItemValue(item->hidpath, &value)) == 1 )
+			{
+				/* not needed as it's already set => item->hidflags &= HU_FLAG_OK; */
 
-	  /* TODO: verify setability/RW with (hData.Attribute != ATTR_DATA_CST) */
-	  dstate_setflags(item->info_type, item->info_flags);
+				/* deal with status items */
+				if (!strncmp(item->info_type, "ups.status", 10))
+				{
+					nutvalue = hu_find_infoval(item->hid2info, (long)value);
+					if (nutvalue != NULL)
+						status_set(nutvalue);
+				}
+				else /* standard items */
+				{
+					/* need lookup'ed translation */
+					if (item->hid2info != NULL)
+					{
+						nutvalue = hu_find_infoval(item->hid2info, (long)value);
+						if (nutvalue != NULL)
+							dstate_setinfo(item->info_type, item->dfl, nutvalue);
+					}
+					else
+						dstate_setinfo(item->info_type, item->dfl, value);
+
+					/* TODO: verify setability/RW with (hData.Attribute != ATTR_DATA_CST) */
+					dstate_setflags(item->info_type, item->info_flags);
+				}
+
+				/* Set max length for strings */
+				if (item->info_flags & ST_FLAG_STRING)
+					dstate_setaux(item->info_type, item->info_len);
+
+				dstate_dataok(); /* atomic call */
+			}
+			else
+			{
+				/* invalidate item */
+				item->hidflags &= ~HU_FLAG_OK;
+			}
+		}
 	}
 
-	/* Set max length for strings */
-	if (item->info_flags & ST_FLAG_STRING)
-	  dstate_setaux(item->info_type, item->info_len);
+	/* Commit the status buffer */
+	status_commit();
 
-	dstate_dataok(); /* atomic call */
-      }
-      else {
-	/* invalidate item */
-	item->hidflags &= ~HU_FLAG_OK;
-      }
-    }
-  }
-
-  /* Commit the status buffer */
-  status_commit();
-
-  /* install handlers */
-  upsh.setvar = setvar;
-  upsh.instcmd = instcmd;
+	/* install handlers */
+	upsh.setvar = setvar;
+	upsh.instcmd = instcmd;
 }
 
 void upsdrv_initups(void)
 {
-  MatchFlags flg;
-  
   /* Search for the first UPS, no matter Mfr or exact product */
   /* TODO: add vartable for VID, PID, Idx => getval*/
   flg.VendorID = MGE_UPS_SYSTEMS; /* limiting to MGE is enough for now! */
@@ -337,7 +389,7 @@ void upsdrv_initups(void)
   flg.UsageCode = hid_lookup_usage("UPS");
   flg.Index = 0x0;
   
-  if ((hd = HIDOpenDevice(device_path, &flg)) == NULL)
+  if ((hd = HIDOpenDevice(device_path, &flg, MODE_OPEN)) == NULL)
     fatalx("No USB/HID UPS found");
   else
     upslogx(1, "Detected an UPS: %s/%s\n", hd->Vendor, hd->Product);
@@ -346,12 +398,14 @@ void upsdrv_initups(void)
   switch (hd->VendorID)
     {
     case MGE_UPS_SYSTEMS:
-      hid_ups = hid_mge;
-      break; 
+		hid_ups = hid_mge;
+		break;
     case APC:
+    case MUSTEK:
     default:
-      fatalx("Manufacturer not supported. Contact driver author <arnaud.quette@free.fr>");
-      /* TODO: call dump_tree() */
+      upslogx(1, "Manufacturer not supported.\nContact driver author <arnaud.quette@free.fr> or <arnaud.quette@mgeups.com> with the below information");
+      HIDDumpTree(NULL);
+      fatalx("Aborting");
       break;       
     }
 }
@@ -376,12 +430,12 @@ static hid_info_t *find_info(const char *varname)
       return hidups_item;
   }
 
-  upsdebugx(2, "find_info: unknown info type: 0x%x\n", varname);
+  upsdebugx(2, "find_info: unknown info type: %s\n", varname);
   return NULL;
 }
 
 /* find the HID Item value matching that NUT value */
-static long hu_find_valinfo(info_lkp_t *hid2info, char* value)
+/* static long hu_find_valinfo(info_lkp_t *hid2info, char* value)
 {
   info_lkp_t *info_lkp;
   
@@ -389,7 +443,7 @@ static long hu_find_valinfo(info_lkp_t *hid2info, char* value)
 	 (strcmp(info_lkp->nut_value, "NULL")); info_lkp++) {
     
     if (!(strcmp(info_lkp->nut_value, value))) {
-      upsdebugx(3, "hu_find_valinfo: found %s (value: %d)\n",
+      upsdebugx(3, "hu_find_valinfo: found %s (value: %s)\n",
 		info_lkp->nut_value, value);
       
       return info_lkp->hid_value;
@@ -397,7 +451,7 @@ static long hu_find_valinfo(info_lkp_t *hid2info, char* value)
   }
   upsdebugx(3, "hu_find_valinfo: no matching HID value for this INFO_* value (%s)", value);
   return -1;
-}
+} */
 
 /* find the NUT value matching that HID Item value */
 static char *hu_find_infoval(info_lkp_t *hid2info, long value)
@@ -410,22 +464,23 @@ static char *hu_find_infoval(info_lkp_t *hid2info, long value)
 	 (strcmp(info_lkp->nut_value, "NULL")); info_lkp++) {
     
     if (info_lkp->hid_value == value) {
-      upsdebugx(3, "hu_find_infoval: found %s (value: %d)\n",
+      upsdebugx(3, "hu_find_infoval: found %s (value: %ld)\n",
 		info_lkp->nut_value, value);
       
       return info_lkp->nut_value;
     }
   }
-  upsdebugx(3, "hu_find_infoval: no matching INFO_* value for this HID value (%d)\n", value);
+  upsdebugx(3, "hu_find_infoval: no matching INFO_* value for this HID value (%ld)\n", value);
   return NULL;
 }
 
 /* All the logic for formatting finely the UPS model name */
 static char *format_model_name(char *iProduct, char *iModel)
 {
-  models_name_t *model = NULL;
-  char *new_name = NULL;
-
+	models_name_t *model = NULL;
+	char *new_name = NULL;
+	float value;
+	
   upsdebugx(2, "Searching for %s\n", iProduct);
 
   /* Search for formatting rules */
@@ -447,9 +502,8 @@ static char *format_model_name(char *iProduct, char *iModel)
     {
     case MGE_UPS_SYSTEMS:
       if (!strncmp(iProduct, "ELLIPSE", 7)) {      
-	if (HIDGetItemValue(model->data2) != -2)
-	  sprintf(iProduct, "%s %i", model->finalname, 
-		  (int)HIDGetItemValue(model->data2));
+	if (HIDGetItemValue(model->data2, &value) == 1)
+	  sprintf(iProduct, "%s %i", model->finalname, (int)value);
 	else
 	  sprintf(iProduct, model->finalname);
       } else {
