@@ -31,7 +31,7 @@
 */
 
 #define DRV_VERSION "0.4"
-#define SEC 2		/*wait time*/
+#define SECS 2		/*wait time*/
 #define USEC 0		/*rest of wait time*/
 
 #include "main.h"
@@ -96,7 +96,7 @@ void upsdrv_initinfo(void)
 	char buffer[256];
 	ser_flush_in(upsfd,"",0);
 	ser_send(upsfd,"%c%s",GET_MFR,COMMAND_END);
-	ser_get_line(upsfd, buffer, sizeof(buffer),ENDCHAR,IGNCHARS,SEC,USEC);
+	ser_get_line(upsfd, buffer, sizeof(buffer),ENDCHAR,IGNCHARS,SECS,USEC);
 	if(strncmp(buffer,MFGR, sizeof(MFGR)))
 		fatalx("Unable to connect to ONEAC UPS on %s\n",device_path);	
  
@@ -114,19 +114,19 @@ void upsdrv_initinfo(void)
 
 	/*firmware revision*/
 	ser_send(upsfd,"%c%s", GET_VERSION, COMMAND_END);
-	ser_get_line(upsfd, buffer, sizeof(buffer),ENDCHAR,IGNCHARS,SEC,USEC);
+	ser_get_line(upsfd, buffer, sizeof(buffer),ENDCHAR,IGNCHARS,SECS,USEC);
 	dstate_setinfo("ups.firmware", "%.3s",buffer);
 
 	/*nominal AC frequency setting --either 50 or 60*/
 	ser_send(upsfd,"%c%s", GET_NOM_FREQ, COMMAND_END);
-	ser_get_line(upsfd,buffer,sizeof(buffer),ENDCHAR,IGNCHARS,SEC,USEC);
+	ser_get_line(upsfd,buffer,sizeof(buffer),ENDCHAR,IGNCHARS,SECS,USEC);
 	dstate_setinfo("input.frequency", "%.2s", buffer);
 
 
 	/*UPS Model (either ON, or EG series of UPS)*/
 	
 	ser_send(upsfd,"%c%s", GET_FAMILY,COMMAND_END);
-	ser_get_line(upsfd,buffer,sizeof(buffer),ENDCHAR,IGNCHARS,SEC,USEC);
+	ser_get_line(upsfd,buffer,sizeof(buffer),ENDCHAR,IGNCHARS,SECS,USEC);
 	dstate_setinfo("ups.model", "%.2s",buffer);
 	printf("Found %.2s family of Oneac UPS\n", buffer);
 
@@ -142,7 +142,7 @@ void upsdrv_initinfo(void)
 			/*nominal input voltage*/
 
 		ser_send(upsfd,"%c%s",GET_NOM_VOLTAGE,COMMAND_END);
-		ser_get_line(upsfd,buffer,sizeof(buffer),ENDCHAR,IGNCHARS,SEC,USEC);
+		ser_get_line(upsfd,buffer,sizeof(buffer),ENDCHAR,IGNCHARS,SECS,USEC);
 
 		switch (buffer[0]) {
 			case V120AC:
@@ -171,7 +171,7 @@ void upsdrv_updateinfo(void)
 	ser_flush_in(upsfd,"",0);  /*just in case*/
 	ser_send (upsfd,"%c%s",GET_ALL,COMMAND_END);
 	ret_value = ser_get_line(upsfd,buffer,sizeof(buffer),ENDCHAR,
-			IGNCHARS,SEC,USEC);
+			IGNCHARS,SECS,USEC);
 	
 	upsdebugx (2,"upsrecv_updateinfo: upsrecv returned: %s\n",buffer);
 	if (ret_value == -1)
@@ -228,7 +228,7 @@ void upsdrv_updateinfo(void)
 					"No transfer yet.");
 				break;
 			default :
-				upslogx(LOG_INFO,"Oneac: Unknown reason for UPS battery",
+				upslogx(LOG_INFO,"Oneac: Unknown reason for UPS battery"
 				" transfer");
 		}
 		/* now update info for only the ON family of UPS*/
