@@ -516,7 +516,7 @@ void upsdrv_initups(void)
 	upsdebugx(1, " frequency calculation coefficients: '{%f,%f}'",
 			                types[type].freq[0], types[type].freq[1]);
 	upsdebugx(1, " load percentage calculation coefficients: "
-                 "'{%f,%f,%f,%f,%f}'",
+                 "'{%f,%f,%f,%f}'",
 	                types[type].loadpct[0], types[type].loadpct[1],
 	                types[type].loadpct[2], types[type].loadpct[3]);
 	upsdebugx(1, " battery percentage calculation coefficients: " 
@@ -524,7 +524,7 @@ void upsdrv_initups(void)
 	                types[type].battpct[0], types[type].battpct[1],
 	                types[type].battpct[2], types[type].battpct[3],
 	                types[type].battpct[4]);
-    upsdebugx(1, " voltage calculation coefficients: '{%f,%f,%f,%f}'",
+    upsdebugx(1, " voltage calculation coefficients: '{%f,%f}'",
 	                    types[type].voltage[2], types[type].voltage[3]);
 
 	/* open serial port */
