@@ -46,9 +46,10 @@
 
 */
 
-#define DRV_VERSION "0.71"
+#define DRV_VERSION "0.72"
 
 #include "main.h"
+#include "serial.h"
 #include "sms.h"
 
 #define ENDCHAR 13	/* replies end with CR */
@@ -57,16 +58,16 @@ static	int	cap_upstemp = 0;
 static	float	lowvolt = 0, voltrange;
 static	int	lownorm, highnorm, poll_failures = 0;
 
-void guessmodel(const char *raw)
+static void guessmodel(const char *raw)
 {
-	char	mch, mstr[256];
+	char	mch, *mstr;
 
 	mch = raw[17];
 
         printf ("0         1         2        3         \n");
         printf ("012345678901234567890123567890123456789\n");
         printf ("%s\n", raw);
-	strlcpy(mstr, &raw[17], sizeof(mstr));
+	mstr = xstrdup(&raw[18]);
 	mstr[10] = '\0';	/* 10 chars max, per the protocol */
        
 	/* trim whitespace */
@@ -74,20 +75,22 @@ void guessmodel(const char *raw)
      
 	dstate_setinfo("ups.model", "SMS %s", mstr);   
 	cap_upstemp = 1;
+
+	free(mstr);
 }
 
-void getbaseinfo(void)
+static void getbaseinfo(void)
 {
 	char	temp[256], model[32], *raw;
 	int	modelnum, i;
 
 	/* dummy read attempt to sync - throw it out */
-	upssend("I\r");
-	upsrecv(temp, sizeof(temp), ENDCHAR, "");
+	ser_send(upsfd, "I\r");
+	ser_get_line(upsfd, temp, sizeof(temp), ENDCHAR, "", 3, 0);
 
 	/* now retrieve information and parse */
-	upssend("I\r");
-	upsrecv(temp, sizeof(temp), ENDCHAR, "");
+	ser_send(upsfd, "I\r");
+	ser_get_line(upsfd, temp, sizeof(temp), ENDCHAR, "", 3, 0);
 	raw = xstrdup(temp);
 
 	if (temp[0] != '#')
@@ -155,50 +158,50 @@ void getbaseinfo(void)
 	free(raw);
 
 	/* paranoia - cancel any shutdown that might already be running */
-	upssend("C\r");
+	ser_send(upsfd, "C\r");
 }
 
-int instcmd(const char *cmdname, const char *extra)
+static int instcmd(const char *cmdname, const char *extra)
 {
 	if (!strcasecmp(cmdname, "test.battery.stop")) {
-		upssend("CT\r");
+		ser_send(upsfd, "CT\r");
 		return STAT_INSTCMD_HANDLED;
 	}
 
 	if (!strcasecmp(cmdname, "test.battery.start")) {
-		upssend("TL\r");/* start battery test until bat low */
+		ser_send(upsfd, "TL\r");/* start battery test until bat low */
 		return STAT_INSTCMD_HANDLED;
 	}
 
 	if (!strcasecmp(cmdname, "test.failure.start")) {
-		upssend("T\r");
+		ser_send(upsfd, "T\r");
 		return STAT_INSTCMD_HANDLED;
 	}
 
 	if (!strcasecmp(cmdname, "shutdown.return")) {
 		/* shutdown and restart */
-		upssend("C\r");
-		upssend("S.3R0003\r");
+		ser_send(upsfd, "C\r");
+		ser_send(upsfd, "S.3R0003\r");
 		return STAT_INSTCMD_HANDLED;
 	}
 
 	if (!strcasecmp(cmdname, "shutdown.stayoff")) {
 		/* shutdown now (one way) */
-		upssend("C\r");
-		upssend("S.3\r");
+		ser_send(upsfd, "C\r");
+		ser_send(upsfd, "S.3\r");
 		return STAT_INSTCMD_HANDLED;
 	}
 
 	if (!strcasecmp(cmdname, "shutdown.stop")) {
 		/* Cancel Shutdown  */
-		upssend("C\r");
+		ser_send(upsfd, "C\r");
 		return STAT_INSTCMD_HANDLED;
 	}
 
 	if (!strcasecmp(cmdname, "reset.watchdog")) {
 		/* WATCHDOG Crontab Function */
-		upssend("C\r");
-		upssend("S05R0003\r");
+		ser_send(upsfd, "C\r");
+		ser_send(upsfd, "S05R0003\r");
 		return STAT_INSTCMD_HANDLED;
 	}
 
@@ -210,11 +213,11 @@ void upsdrv_initinfo(void)
 {
 	getbaseinfo();
 
-	upsh.new_instcmd = instcmd;
+	upsh.instcmd = instcmd;
 	dstate_setinfo("driver.version.internal", "%s", DRV_VERSION);
 }
 
-void pollfail(char *why)
+static void pollfail(const char *why)
 {
 	poll_failures++;
 
@@ -228,13 +231,13 @@ void pollfail(char *why)
 void upsdrv_updateinfo(void)
 {
 	char	temp[256], utility[16], loadpct[16], acfreq[16], battvolt[16],
-		upstemp[16], stat[16], outvolt[16];
+		upstemp[16], pstat[16], outvolt[16];
 	int	util, ret;
 	double	bvoltp;
 
-	upssend("Q1\r");
+	ser_send(upsfd, "Q1\r");
 
-	ret = upsrecv (temp, sizeof(temp), ENDCHAR, "");
+	ret = ser_get_line(upsfd, temp, sizeof(temp), ENDCHAR, "", 3, 0);
 
 	/* sanity checks for poll data */
 	if (strlen(temp) < 46) {
@@ -268,7 +271,7 @@ void upsdrv_updateinfo(void)
 	 */
 
 	sscanf(temp, "%*c%s %*s %s %s %s %s %s %s", utility, outvolt, loadpct,
-		acfreq, battvolt, upstemp, stat);
+		acfreq, battvolt, upstemp, pstat);
 
 	dstate_setinfo("output.voltage", "%s", outvolt);
 	dstate_setinfo("input.voltage", "%s", utility);
@@ -285,11 +288,11 @@ void upsdrv_updateinfo(void)
 
 	util = atoi(utility);
 
-	if (stat[0] == '0') {
+	if (pstat[0] == '0') {
 		status_set("OL");		/* on line */
 
 		/* only allow these when OL since they're bogus when OB */
-		if (stat[2] == '1') {		/* boost or trim in effect */
+		if (pstat[2] == '1') {		/* boost or trim in effect */
 			if (util < lownorm)
 				status_set("BOOST");
 
@@ -301,7 +304,7 @@ void upsdrv_updateinfo(void)
 		status_set("OB");		/* on battery */
 	}
 
-	if (stat[1] == '1')
+	if (pstat[1] == '1')
 		status_set("LB");		/* low battery */
 
 	status_commit();
@@ -318,26 +321,26 @@ void upsdrv_updateinfo(void)
 /* power down the attached load immediately */
 void upsdrv_shutdown(void)
 {
-	char	temp[256], stat[32];
+	char	temp[256], pstat[32];
 
 	/* basic idea: find out line status and send appropriate command */
 
-	upssend("Q1\r");
-	upsrecv (temp, sizeof(temp), ENDCHAR, "");
-	sscanf (temp, "%*s %*s %*s %*s %*s %*s %*s %s", stat);
+	ser_send(upsfd, "Q1\r");
+	ser_get_line(upsfd, temp, sizeof(temp), ENDCHAR, "", 3, 0);
+	sscanf (temp, "%*s %*s %*s %*s %*s %*s %*s %s", pstat);
 
 	/* on battery: send S01<cr>, ups will return by itself on utility */
 	/* on line: send S01R0003<cr>, ups will cycle and return soon */
 
-	upssend("S01");
+	ser_send(upsfd, "S01");
 
-	if (stat[0] == '0') {			/* on line */
+	if (pstat[0] == '0') {			/* on line */
 		printf("On line, sending shutdown+return command...\n");
-		upssend("R0003");
+		ser_send(upsfd, "R0003");
 	} else
 		printf("On battery, sending normal shutdown command...\n");
 
-	upssendchar(13);	/* end sequence */
+	ser_send_char(upsfd, 13);	/* end sequence */
 }
 
 void upsdrv_help(void)
@@ -357,9 +360,11 @@ void upsdrv_banner(void)
 
 void upsdrv_initups(void)
 {
-	open_serial(device_path, B2400);
+	upsfd = ser_open(device_path);
+	ser_set_speed(upsfd, device_path, B2400);
 }
 
 void upsdrv_cleanup(void)
 {
+	ser_close(upsfd, device_path);
 }
