@@ -2,12 +2,13 @@
  *
  *  Based on NetSNMP API (Simple Network Management Protocol V1-2)
  *
- *  Copyright (C) 2002-2003 
+ *  Copyright (C) 2002-2004 
  *  			Arnaud Quette <arnaud.quette@free.fr>
  *  			Dmitry Frolov <frolov@riss-telecom.ru>
  *  			J.W. Hoogervorst <jeroen@hoogervorst.net>
+ *  			Niels Baggesen <niels@baggesen.net>
  *
- *  Sponsored by MGE UPS SYSTEMS <http://www.mgeups.com>
+ *  Sponsored by MGE UPS SYSTEMS <http://opensource.mgeups.com/>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -178,8 +179,8 @@ void nut_snmp_init(const char *type, const char *hostname, const char *community
 	/* Initialize session */
 	snmp_sess_init(&g_snmp_sess);
 
-	g_snmp_sess.peername = (char *)hostname;
-	g_snmp_sess.community = (char *)community;
+	g_snmp_sess.peername = xstrdup(hostname);
+	g_snmp_sess.community = xstrdup(community);
 	g_snmp_sess.community_len = strlen(community);
 	g_snmp_sess.version = SNMP_VERSION_1;
 
@@ -484,7 +485,7 @@ void nut_snmp_perror(struct snmp_session *sess, int status,
 				upsname, buf, snmp_errstring(response->errstat));
 	} else if (status == STAT_TIMEOUT) {
 		upslogx(LOG_ERR, "[%s] %s: Timeout: no response from %s",
-			upsname, sess->peername);
+			upsname, buf, sess->peername);
 	} else {
 		snmp_sess_error(sess, &cliberr, &snmperr, &snmperrstr);
 		upslogx(LOG_ERR, "[%s] %s: %s",
@@ -538,7 +539,7 @@ void su_setinfo(const char *type, const char *value, int flags, int auxdata)
 
 void su_status_set(snmp_info_t *su_info_p, long value)
 {	
-	char *info_value = NULL;
+	const char *info_value = NULL;
 
 	upsdebugx(2, "SNMP UPS driver : entering su_status_set()");
 
@@ -562,12 +563,12 @@ snmp_info_t *su_find_info(const char *type)
 		if (!strcasecmp(su_info_p->info_type, type))
 			return su_info_p;
 		
-	fatalx("nut_snmp_find_info: unknown info type: 0x%x", type);
+	fatalx("nut_snmp_find_info: unknown info type: %s", type);
 	return NULL;
 }
 
 /* Load the right snmp_info_t structure matching mib parameter */
-void load_mib2nut(char *mib)
+void load_mib2nut(const char *mib)
 {
 	upsdebugx(2, "SNMP UPS driver : entering load_mib2nut(%s)", mib);
 	
@@ -599,18 +600,18 @@ long su_find_valinfo(info_lkp_t *oid2info, char* value)
 		(strcmp(info_lkp->info_value, "NULL")); info_lkp++) {
 			
 		if (!(strcmp(info_lkp->info_value, value))) {
-			upsdebugx(1, "su_find_valinfo: found %s (value: %d)",
+			upsdebugx(1, "su_find_valinfo: found %s (value: %s)",
 					info_lkp->info_value, value);
 			
 			return info_lkp->oid_value;
 		}
 	}
-	upsdebugx(1, "su_find_infoval: no matching INFO_* value for this OID value (%d)", value);
+	upsdebugx(1, "su_find_infoval: no matching INFO_* value for this OID value (%s)", value);
 	return -1;
 }
 
 /* find the INFO_* value matching that OID value */
-char *su_find_infoval(info_lkp_t *oid2info, long value)
+const char *su_find_infoval(info_lkp_t *oid2info, long value)
 {
 	info_lkp_t *info_lkp;
 		
@@ -618,13 +619,13 @@ char *su_find_infoval(info_lkp_t *oid2info, long value)
 		(strcmp(info_lkp->info_value, "NULL")); info_lkp++) {
 			
 		if (info_lkp->oid_value == value) {
-			upsdebugx(1, "su_find_infoval: found %s (value: %d)",
+			upsdebugx(1, "su_find_infoval: found %s (value: %ld)",
 					info_lkp->info_value, value);
 			
 			return info_lkp->info_value;
 		}
 	}
-	upsdebugx(1, "su_find_infoval: no matching INFO_* value for this OID value (%d)", value);
+	upsdebugx(1, "su_find_infoval: no matching INFO_* value for this OID value (%ld)", value);
 	return NULL;
 }
 
@@ -715,7 +716,7 @@ bool su_ups_get(snmp_info_t *su_info_p)
 		if (status == TRUE)
 		{
 			su_status_set(su_info_p, value);
-			upsdebugx(2, "=> value: %d", value);
+			upsdebugx(2, "=> value: %ld", value);
 		}
 
 		return status;
@@ -958,7 +959,7 @@ void read_mibconf(char *mib)
 				snprintfcat(errmsg, sizeof(errmsg), " %s", 
 					ctx.arglist[i]);
 
-			upslogx(LOG_WARNING, errmsg);
+			upslogx(LOG_WARNING, "%s", errmsg);
 		}
 	}
 	pconf_finish(&ctx);		
