@@ -1,13 +1,14 @@
 /*  snmp-ups.h - NUT Meta SNMP driver (support different MIBS)
  *
- *  Based on UCD/NetSNMP API (Simple Network Management Protocol V1-2)
+ *  Based on NET-SNMP API (Simple Network Management Protocol V1-2)
  *
- *  Copyright (C) 2002-2003 
+ *  Copyright (C) 2002-2004 
  *  			Arnaud Quette <arnaud.quette@free.fr>
  *  			Dmitry Frolov <frolov@riss-telecom.ru>
  *  			J.W. Hoogervorst <jeroen@hoogervorst.net>
+ *  			Niels Baggesen <niels@baggesen.net>
  *
- *  Sponsored by MGE UPS SYSTEMS <http://www.mgeups.com/opensource/>
+ *  Sponsored by MGE UPS SYSTEMS <http://opensource.mgeups.com/>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,11 +31,11 @@
 - add enum values to OIDs.
 - optimize network flow by constructing one big packet (calling snmp_add_null_var
 for each OID request we made), instead of sending many small packets
-- add support for registration and traps (needed ?),
+- add support for registration and traps (manager mode),
 - complete mib2nut data (add all OID translation to NUT)
 - externalize mib2nut data in .m2n files and load at driver startup using parseconf()...
 - ... and use Net-SNMP lookup mecanism for OIDs (use string path, not numeric)
-- add mib autodetection support (=> -x mibs=auto),
+- add mib autodetection support (=> -x mibs=auto) and make it the default (instead of ietf),
 - adjust information logging.
 */
 
@@ -43,9 +44,18 @@ for each OID request we made), instead of sending many small packets
 #include <stdlib.h>
 #include <string.h>
 #include <net-snmp/net-snmp-config.h>
+/* workaround for buggy Net-SNMP config */
+#undef PACKAGE_BUGREPORT
+#undef PACKAGE_NAME
+#undef PACKAGE_VERSION
+#undef PACKAGE_STRING
+#undef PACKAGE_TARNAME
+#undef HAVE_DMALLOC_H
 #include <net-snmp/net-snmp-includes.h>
 
-#define DRIVER_VERSION		"0.40"
+#include "attribute.h"
+
+#define DRIVER_VERSION		"0.41"
 
 #define DEFAULT_POLLFREQ	30		/* in seconds */
 
@@ -69,7 +79,7 @@ typedef int bool;
 /* for lookup between OID values and INFO_ value */
 typedef struct {
 	int oid_value;		/* OID value */
-	char *info_value;	/* INFO_* value */
+	const char *info_value;	/* INFO_* value */
 } info_lkp_t;
 
 /* Structure containing info about one item that can be requested
@@ -78,12 +88,12 @@ typedef struct {
    are converted according to the multiplier table  
 */
 typedef struct {
-	char	*info_type;		/* INFO_ or CMD_ element */
+	const char	*info_type;		/* INFO_ or CMD_ element */
 	int		info_flags;		/* flags to set in addinfo */
 	float	info_len;		/* length of strings if STR, */
 							/* cmd value if CMD, multiplier otherwise. */
-	char	*OID;			/* SNMP OID or NULL */
-	char	*dfl;			/* default value */
+	const char	*OID;			/* SNMP OID or NULL */
+	const char	*dfl;			/* default value */
 	unsigned long flags;	/* my flags */
 	info_lkp_t *oid2info;	/* lookup table between OID and NUT values */
 /*	char *info_OID_format;		*//* FFE: OID format for complex values */
@@ -149,7 +159,8 @@ bool nut_snmp_set(const char *OID, char type, const char *value);
 bool nut_snmp_set_str(const char *OID, const char *value);
 bool nut_snmp_set_int(const char *OID, long value);
 void nut_snmp_perror(struct snmp_session *sess,  int status,
-	struct snmp_pdu *response, const char *fmt, ...);
+	struct snmp_pdu *response, const char *fmt, ...)
+	__attribute__ ((__format__ (__printf__, 4, 5)));
 		
 void su_startup(void);
 void su_cleanup(void);
@@ -162,9 +173,9 @@ snmp_info_t *su_find_info(const char *type);
 bool snmp_ups_walk(int mode);
 bool su_ups_get(snmp_info_t *su_info_p);
 
-void load_mib2nut(char *mib);
+void load_mib2nut(const char *mib);
 	
-char *su_find_infoval(info_lkp_t *oid2info, long value);
+const char *su_find_infoval(info_lkp_t *oid2info, long value);
 long su_find_valinfo(info_lkp_t *oid2info, char* value);
 
 int su_setvar(const char *varname, const char *val);
@@ -175,6 +186,6 @@ void read_mibconf(char *mib);
 
 extern char *upsname;
 struct snmp_session g_snmp_sess, *g_snmp_sess_p;
-char *OID_pwr_status;
+const char *OID_pwr_status;
 int g_pwr_battery;
 int pollfreq; /* polling frequency */
