@@ -2,7 +2,7 @@
  *
  *  victron.c - Model specific routines for GE/IMV/Victron  units
  *  Match, Match Lite, NetUps
- *  Revision 0.1.8
+ *  Revision 0.1.9
  *           
  * Copyright (C) 1999  Russell Kroll <rkroll@exploits.org>
  * Copyright (C) 2000  Radek Benedikt <benedikt@lphard.cz>
@@ -12,6 +12,9 @@
  * Copyright (C) 2003  Gert Lynge <gert@lynge.org>
  * Porting to new serial functions. Now removes \n from data (was causing
  * periodic misreadings of temperature and voltage levels)
+ * Copyright (C) 2004  Gert Lynge <gert@lynge.org>
+ * Implemented some Instant Commands.
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -29,13 +32,13 @@
  *
  */
 
-#define DRV_VERSION "0.1.8"
+#define DRV_VERSION "0.1.9"
 
 #include "main.h"
 #include "serial.h"
 
 #define ENDCHAR	'\r'
-#define IGNCHARS	"\n"
+#define IGNCHARS "\n"
 
 #define UPS_DELAY 150000
 #define UPS_LONG_DELAY 450000
@@ -45,6 +48,13 @@
 #define VICTRON_OB 2
 #define VICTRON_LB 4
 
+#define VICTRON_NO_TEST		1
+#define VICTRON_ABORT_TEST	2
+#define VICTRON_SYSTEM_TEST	3
+#define VICTRON_BATTERY_TEST	4
+#define VICTRON_CALIBRATION	5
+#define VICTRON_BYPASS_TEST	101
+
 #define LENGTH_TEMP 256
 
 int  sdwdelay = 0;  /* shutdown after 0 second */
@@ -61,6 +71,7 @@ static int exist_battery_current = 0;
 static int exist_battery_temperature = 0;
 static int exist_battery_runtime = 0;
 
+static int test_in_progress = VICTRON_NO_TEST;
 
 static int get_data (const char *out_string, char *in_string)
 {
@@ -76,6 +87,124 @@ static int get_data (const char *out_string, char *in_string)
 	return 0;
 }
 
+static int instcmd(const char *cmdname, const char *extra)
+{
+	char temp[ LENGTH_TEMP ]; 
+
+	if(!strcasecmp(cmdname, "calibrate.start"))
+	{
+		if(get_data("vTi5!",temp))
+		{
+			upsdebugx(1, "instcmd: ser_send calibrate.start failed");
+			return STAT_INSTCMD_UNKNOWN; /* Or Failed when it get defined */
+		}
+		else
+		{
+			upsdebugx(1, "instcmd: calibrate.start returned: %s", temp);
+			test_in_progress = VICTRON_CALIBRATION;
+			return STAT_INSTCMD_HANDLED;
+		}
+	}		
+	else if(!strcasecmp(cmdname, "calibrate.stop"))
+	{
+		if(get_data("vTi2!",temp))
+		{
+			upsdebugx(1, "instcmd: ser_send calibrate.stop failed");
+			return STAT_INSTCMD_UNKNOWN; /* Or Failed when it get defined */
+		}
+		else
+		{
+			upsdebugx(1, "instcmd: calibrate.stop returned: %s", temp);
+			return STAT_INSTCMD_HANDLED;
+		}
+	}		
+	else if(!strcasecmp(cmdname, "test.battery.stop"))
+	{
+		if(get_data("vTi2!",temp))
+		{
+			upsdebugx(1, "instcmd: ser_send test.battery.stop failed");
+			return STAT_INSTCMD_UNKNOWN; /* Or Failed when it get defined */
+		}
+		else
+		{
+			upsdebugx(1, "instcmd: test.battery.stop returned: %s", temp);
+			return STAT_INSTCMD_HANDLED;
+		}
+	}
+	else if(!strcasecmp(cmdname, "test.battery.start"))
+	{
+		if(get_data("vTi4!",temp))
+		{
+			upsdebugx(1, "instcmd: ser_send test.battery.start failed");
+			return STAT_INSTCMD_UNKNOWN; /* Or Failed when it get defined */
+		}
+		else
+		{
+			upsdebugx(1, "instcmd: test.battery.start returned: %s", temp);
+			test_in_progress = VICTRON_BATTERY_TEST;
+			return STAT_INSTCMD_HANDLED;
+		}
+	}
+	else if(!strcasecmp(cmdname, "test.panel.stop"))
+	{
+		if(get_data("vTi2!",temp))
+		{
+			upsdebugx(1, "instcmd: ser_send test.panel.stop failed");
+			return STAT_INSTCMD_UNKNOWN; /* Or Failed when it get defined */
+		}
+		else
+		{
+			upsdebugx(1, "instcmd: test.panel.stop returned: %s", temp);
+			return STAT_INSTCMD_HANDLED;
+		}
+	}
+	else if(!strcasecmp(cmdname, "test.panel.start"))
+	{
+		if(get_data("vTi3!",temp))
+		{
+			upsdebugx(1, "instcmd: ser_send test.panel.start failed");
+			return STAT_INSTCMD_UNKNOWN; /* Or Failed when it get defined */
+		}
+		else
+		{
+			upsdebugx(1, "instcmd: test.panel.start returned: %s", temp);
+			test_in_progress = VICTRON_SYSTEM_TEST;
+			return STAT_INSTCMD_HANDLED;
+		}
+	}
+	else if(!strcasecmp(cmdname, "bypass.stop"))
+	{
+		if(get_data("vTi2!",temp))
+		{
+			upsdebugx(1, "instcmd: ser_send bypass.stop failed");
+			return STAT_INSTCMD_UNKNOWN; /* Or Failed when it get defined */
+		}
+		else
+		{
+			upsdebugx(1, "instcmd: bypass.stop returned: %s", temp);
+			return STAT_INSTCMD_HANDLED;
+		}
+	}
+	else if(!strcasecmp(cmdname, "bypass.start"))
+	{
+		if(get_data("vTi101!",temp))
+		{
+			upsdebugx(1, "instcmd: ser_send bypass.start failed");
+			return STAT_INSTCMD_UNKNOWN; /* Or Failed when it get defined */
+		}
+		else
+		{
+			upsdebugx(1, "instcmd: bypass.start returned: %s", temp);
+			test_in_progress = VICTRON_BYPASS_TEST;
+			return STAT_INSTCMD_HANDLED;
+		}
+	}
+	else
+	{
+		upsdebugx(1, "instcmd: unknown command: %s", cmdname);
+		return STAT_INSTCMD_UNKNOWN;
+	}
+}
 	
 void upsdrv_initinfo(void)
 {
@@ -84,6 +213,16 @@ void upsdrv_initinfo(void)
 	if (model_name)
 		dstate_setinfo("ups.model", "%s", model_name);
 
+	upsh.instcmd = instcmd;
+
+	dstate_addcmd("test.battery.start");
+	dstate_addcmd("test.battery.stop");
+	dstate_addcmd("calibrate.start");
+	dstate_addcmd("calibrate.stop");
+	dstate_addcmd("test.panel.start");	/* We need a GeneralSystemTest, but use this one instead */
+	dstate_addcmd("test.panel.stop");	/* We need a GeneralSystemTest, but use this one instead */
+	dstate_addcmd("bypass.start");
+	dstate_addcmd("bypass.stop");
 }
 
 
@@ -91,6 +230,7 @@ void upsdrv_updateinfo(void)
 {
 	int flags; 
 	char temp[ LENGTH_TEMP ]; 
+	char test_result[ 255 ];
 	int runtime_sec = -1;
 
         if (start_is_datastale)
@@ -148,11 +288,54 @@ void upsdrv_updateinfo(void)
 		status_set("OB");
 	else
 		status_set("OL");
+	  
+	/* Get UPS test results */
+	if (get_data("vTr?",temp)) return;
+	if (get_data("vTd?",test_result)) return;
+	
+	switch(atoi(temp+3))
+	{
+		case 1:
+		upsdebugx(1, "upsdrv_updateinfo: test %i result = Done, Passed: %s",test_in_progress,test_result+3);
+		test_in_progress = VICTRON_NO_TEST;
+		break;
+
+		case 2:
+		upsdebugx(1, "upsdrv_updateinfo: test %i result = Done, Warning: %s",test_in_progress,test_result+3);
+		test_in_progress = VICTRON_NO_TEST;
+		break;
+
+		case 3:
+		upsdebugx(1, "upsdrv_updateinfo: test %i result = Done, Error: %s",test_in_progress,test_result+3);
+		test_in_progress = VICTRON_NO_TEST;
+		break;
+
+		case 4:
+		upsdebugx(1, "upsdrv_updateinfo: test %i result = Aborted: %s",test_in_progress,test_result+3);
+		test_in_progress = VICTRON_NO_TEST;
+		break;
+
+		case 5:
+		if(test_in_progress==VICTRON_CALIBRATION)
+	                status_set("CAL");              /* calibration in progress*/
+		upsdebugx(1, "upsdrv_updateinfo: test %i result = In Progress: %s",
+			test_in_progress,test_result+3);
+		break;
+
+		case 6:
+		upsdebugx(1, "upsdrv_updateinfo: test result = No test initiated: %s",
+			test_result+3);
+		break;
+		
+		default:
+		upsdebugx(1, "upsdrv_updateinfo: unknown test result: %s / %s",temp+3,test_result+3);
+		break;
+	}
 
 	status_commit();
 	/* dstate_dataok(); */
 
-	upsdebugx(1, "ups.status = %s\n", dstate_getinfo("ups.status"));
+	upsdebugx(1, "upsdrv_updateinfo: ups.status = %s\n", dstate_getinfo("ups.status"));
   
 
 	/************** ups.x ***************************/
@@ -312,33 +495,6 @@ void upsdrv_shutdown(void)
 	ser_send(upsfd, "vCb%i!%c", sdwdelay, ENDCHAR); 
 }
 
-
-#if 0           /* this code isn't used anywhere */
-void instcmd (int auxcmd, int dlen, char *data)
-{
-	/* TODO: reply to upsd? */
-	/* Code has not been ported to new serial functions yet */
-
-	switch (auxcmd) {
-		/* case test.battery.stop:	* stop battery test *
-		 *	ser_send_...("vTi2");
-		 *	break;
-		 * case test.battery.start:	* start battery test *
-		 *	ser_send_...("vTi4");
-		 *	break;
-		 * case calibrate.stop:	        * stop calibration *
-		 *	ser_send_...("vTi2");
-		 *	break;
-		 * case calibrate.start:	* start calibration *
-		 *	ser_send_...("vTi5");
-		 *	break;
-		 */
-		default:
-			upslogx(LOG_INFO, "instcmd: unknown type 0x%04x", auxcmd);
-	}
-}
-#endif
-
 void upsdrv_help(void)
 {
 }
