@@ -34,6 +34,7 @@
 #include <unistd.h>
 #include <assert.h>
 
+#include "attribute.h"
 #include "config.h"
 #include "proto.h"
 #include "version.h"
@@ -59,7 +60,8 @@ void writepid(const char *name);
 /* send a signal to another running process */
 void sendsignal(const char *progname, int sig);
 
-int snprintfcat(char *dst, size_t size, const char *fmt, ...);
+int snprintfcat(char *dst, size_t size, const char *fmt, ...)
+	__attribute__ ((__format__ (__printf__, 3, 4)));
 
 /* open <pidfn>, get the pid, then send it <sig> */
 void sendsignalfn(const char *pidfn, int sig);
@@ -78,13 +80,19 @@ const char * dflt_statepath(void);
 /* Return the alternate path for pid files */
 const char * altpidpath(void);
 
-void upslog(int priority, const char *fmt, ...);
-void upslogx(int priority, const char *fmt, ...);
-void upsdebug(int level, const char *fmt, ...);
-void upsdebugx(int level, const char *fmt, ...);
+void upslog(int priority, const char *fmt, ...)
+	__attribute__ ((__format__ (__printf__, 2, 3)));
+void upslogx(int priority, const char *fmt, ...)
+	__attribute__ ((__format__ (__printf__, 2, 3)));
+void upsdebug(int level, const char *fmt, ...)
+	__attribute__ ((__format__ (__printf__, 2, 3)));
+void upsdebugx(int level, const char *fmt, ...)
+	__attribute__ ((__format__ (__printf__, 2, 3)));
 
-void fatal(const char *fmt, ...);
-void fatalx(const char *fmt, ...);
+void fatal(const char *fmt, ...)
+	__attribute__ ((__format__ (__printf__, 1, 2)));
+void fatalx(const char *fmt, ...)
+	__attribute__ ((__format__ (__printf__, 1, 2)));
 
 extern int nut_debug_level;
 
