@@ -1,3 +1,5 @@
+#include "attribute.h"
+
 #if !defined(HAVE_SNPRINTF) || !defined(HAVE_VSNPRINTF)
 
 /* Define this as a fall through, HAVE_STDARG_H is probably already set */
@@ -28,7 +30,8 @@
 # endif
 #endif
 
-int snprintf (char *str, size_t count, const char *fmt, ...);
+int snprintf (char *str, size_t count, const char *fmt, ...)
+	__attribute__ ((__format__ (__printf__, 3, 4)));
 int vsnprintf (char *str, size_t count, const char *fmt, va_list arg);
 #endif
 
