@@ -17,17 +17,19 @@
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
 
-void read_upsdconf(int reloading);
-void upsconf_add(int reloading);
-void reload_config(void);
+/* startup: read all config files (upsd.conf, ups.conf, upsd.users) */
+void conf_load(void);
+
+/* flush existing config, then reread everything */
+void conf_reload(void);
 
 typedef struct {
-	char    *upsname;
-	char    *driver;
+	char	*upsname;
+	char	*driver;
 	char	*port;
 	char	*desc;
-	void    *next;
-}       ups_t;
+	void	*next;
+}	ups_t;
 
 /* link to user.c for flushing during reloads */
 void user_flush(void);
@@ -35,3 +37,5 @@ void user_flush(void);
 /* used for really clean shutdowns */
 void delete_acls(void);
 void delete_access(void);
+
+	extern	int	num_ups;
