@@ -19,12 +19,13 @@
 
 #include "common.h"
 
-#include "upstype.h"
 #include "upsd.h"
 #include "sstate.h"
 #include "state.h"
 #include "neterr.h"
 
+#include "netlist.h"
+
 	extern	upstype	*firstups;	/* for list_ups */
 
 static int tree_dump(struct st_tree_t *node, ctype *client, const char *ups, 
@@ -216,53 +217,52 @@ static void list_ups(ctype *client)
 	sendback(client, "END LIST UPS\n");
 }	
 
-int net_list(ctype *client, int numarg, char **arg)
+void net_list(ctype *client, int numarg, const char **arg)
 {
 	if (numarg < 1) {
 		send_err(client, NUT_ERR_INVALID_ARGUMENT);
-		return 1;
+		return;
 	}
 
 	/* LIST UPS */
 	if (!strcasecmp(arg[0], "UPS")) {
 		list_ups(client);
-		return 1;
+		return;
 	}
 
 	if (numarg < 2) {
 		send_err(client, NUT_ERR_INVALID_ARGUMENT);
-		return 1;
+		return;
 	}
 
 	/* LIST VAR UPS */
 	if (!strcasecmp(arg[0], "VAR")) {
 		list_var(client, arg[1]);
-		return 1;
+		return;
 	}
 
 	/* LIST RW UPS */
 	if (!strcasecmp(arg[0], "RW")) {
 		list_rw(client, arg[1]);
-		return 1;
+		return;
 	}
 
 	/* LIST CMD UPS */
 	if (!strcasecmp(arg[0], "CMD")) {
 		list_cmd(client, arg[1]);
-		return 1;
+		return;
 	}
 
 	if (numarg < 3) {
 		send_err(client, NUT_ERR_INVALID_ARGUMENT);
-		return 1;
+		return;
 	}
 
 	/* LIST ENUM UPS VARNAME */
 	if (!strcasecmp(arg[0], "ENUM")) {
 		list_enum(client, arg[1], arg[2]);
-		return 1;
+		return;
 	}
 
 	send_err(client, NUT_ERR_INVALID_ARGUMENT);
-	return 1;
 }
