@@ -76,7 +76,7 @@ static void set_var(ctype *client, const char *upsname, const char *var,
 		/* check for insanity from the driver */
 		if (aux < 1) {
 			upslogx(LOG_WARNING, "UPS [%s]: auxdata for %s is invalid",
-				var);
+				ups->name, var);
 
 			send_err(client, NUT_ERR_SET_FAILED);
 			return;
