@@ -29,6 +29,8 @@
 #include "ctype.h"
 #include "neterr.h"
 
+#include "ssl.h"
+
 	char	*certfile = NULL;
 
 static	int	ssl_initialized = 0;
@@ -36,9 +38,10 @@ static	int	ssl_initialized = 0;
 #ifndef HAVE_SSL
 
 /* stubs for non-ssl compiles */
-void do_starttls(ctype *client, char *arg, char *rest)
+void net_starttls(ctype *client, int numarg, const char **arg)
 {
 	send_err(client, NUT_ERR_FEATURE_NOT_SUPPORTED);
+	return;
 }
 
 int ssl_write(ctype *client, const char *buf, size_t buflen)
@@ -80,7 +83,7 @@ static void ssl_debug(void)
 	}
 }
 
-void do_starttls(ctype *client, char *arg, char *rest)
+void net_starttls(ctype *client, int numarg, const char **arg)
 {
 	if (client->ssl) {
 		send_err(client, NUT_ERR_ALREADY_SSL_MODE);
@@ -172,10 +175,10 @@ static int ssl_error(SSL *ssl, int ret)
 					ret);
 			break;
 
-	        default:
+		default:
 			upsdebugx(1, "ssl_error() ret=%d SSL_ERROR %d", ret, e);
 			ssl_debug();
-        }
+	}
 
 	return -1;
 }
