@@ -33,142 +33,6 @@
 #include "sstate.h"
 #include "state.h"
 
-	/* until old-style vars are gone */
-#include "shared-tables.h"
-#include "var-map.h"
-#include "cmd-map.h"
-
-	/* upsd.c pulls in the initializers, so just reference those */
-	extern	struct	netvars_t	netvars[];
-	extern	struct	instcmds_t	instcmds[];
-	extern	struct	var_map_t	var_map[];
-	extern	struct	cmd_map_t	cmd_map[];
-
-static const char *newcmd_to_old(const char *new)
-{
-	int	i;
-
-	for (i = 0; cmd_map[i].name != NULL; i++)
-		if (!strcasecmp(cmd_map[i].name, new))
-			return cmd_map[i].old;
-
-	return NULL;
-}
-
-/* convert temporary hex numerics to the old-style cmdnames */
-static void append_oldcmdname(char *buf, size_t bufsize, const char *cmdname)
-{
-	int	i, cmd;
-
-	/* only handle old-style stuff (no periods, and 4 chars long) */
-	if ((strchr(cmdname, '.')) || (strlen(cmdname) != 4)) {
-		const	char	*old;
-
-		old = newcmd_to_old(cmdname);
-
-		if (!old) {
-			upsdebugx(2, "Unhandled new command name [%s]",
-				cmdname);
-			return;
-		}
-
-		snprintfcat(buf, bufsize, " %s", old);
-		return;
-	}
-
-	cmd = strtol(cmdname, (char **) NULL, 16);
-
-	if (cmd < 0)
-		return;
-
-	/* yeah, it's ugly, but it's going away, so ignore it for now */
-	for (i = 0; instcmds[i].name != NULL; i++) {
-		if (instcmds[i].cmd == cmd) {
-			snprintfcat(buf, bufsize, " %s", instcmds[i].name);
-			return;
-		}
-	}
-
-	/* odd ... */
-
-	upslogx(LOG_NOTICE, "Failed to find %04X in instcmds (%d)\n", cmd, i);
-}
-
-static const char *newvar_to_old(const char *new)
-{
-	int	i;
-
-	for (i = 0; var_map[i].name != NULL; i++)
-		if (!strcasecmp(var_map[i].name, new))
-			return var_map[i].old;
-
-	return NULL;
-}
-
-/* convert temporary hex numerics to the old-style varnames */
-static void append_oldinfoname(char *buf, size_t bufsize, const char *varname)
-{
-	int	i, var;
-
-	/* only handle old-style stuff (no periods, and 4 chars long) */
-	if ((strchr(varname, '.')) || (strlen(varname) != 4)) {
-		const	char	*old;
-
-		old = newvar_to_old(varname);
-
-		if (!old) {
-			upsdebugx(2, "Unhandled new variable name [%s]",
-				varname);
-			return;
-		}
-
-		snprintfcat(buf, bufsize, " %s", old);
-		return;
-	}
-
-	var = strtol(varname, (char **) NULL, 16);
-
-	if (var < 0)
-		return;
-
-	/* yeah, it's ugly, but it's going away, so ignore it for now */
-	for (i = 0; netvars[i].name != NULL; i++) {
-		if (netvars[i].type == var) {
-			snprintfcat(buf, bufsize, " %s", netvars[i].name);
-			return;
-		}
-	}
-
-	/* odd ... */
-
-	upslogx(LOG_NOTICE, "Failed to find %04X in netvars (%d)\n", var, i);
-}
-
-/* walk the tree and build an old-style variable list */
-static void geninfolist(struct st_tree_t *node, char *buf, size_t bufsize, 
-	int rw)
-{
-	if (!node)
-		return;
-
-	if (node->left)
-		geninfolist(node->left, buf, bufsize, rw);
-
-	if (rw) {
-
-		/* only list rw entries */
-		if (node->flags & ST_FLAG_RW)
-			append_oldinfoname(buf, bufsize, node->var);
-	} else {
-
-		/* list all entries */
-		append_oldinfoname(buf, bufsize, node->var);
-	}
-
-	if (node->right)
-		geninfolist(node->right, buf, bufsize, rw);
-}
-
 /* set the 'last heard' time to now for later staleness checks */
 static void update_time(upstype *ups)
 {
@@ -262,7 +126,7 @@ static int parse_args(upstype *ups, int numargs, char **arg)
 static void sendping(upstype *ups, time_t now, int maxage)
 {
 	int	ret;
-	char	*cmd = "PING\n";
+	const	char	*cmd = "PING\n";
 
 	/* don't beat the driver to death with pings */
 	if (difftime(now, ups->last_ping) < (maxage / 2))
@@ -272,12 +136,12 @@ static void sendping(upstype *ups, time_t now, int maxage)
 
 	ret = write(ups->sock_fd, cmd, strlen(cmd));
 
-	if (ret != strlen(cmd)) {
+	if ((ret < 1) || (ret != (int) strlen(cmd))) {
 		upslog(LOG_NOTICE, "Send ping to UPS [%s] failed", ups->name);
 
-                sstate_infofree(ups);
-                sstate_cmdfree(ups);
-                pconf_finish(&ups->sock_ctx);
+		sstate_infofree(ups);
+		sstate_cmdfree(ups);
+		pconf_finish(&ups->sock_ctx);
 
 		close(ups->sock_fd);
 		ups->sock_fd = -1;
@@ -293,7 +157,7 @@ static void sendping(upstype *ups, time_t now, int maxage)
 int sstate_connect(upstype *ups)
 {
 	int	ret, fd;
-	char	*dumpcmd = "DUMPALL\n";
+	const	char	*dumpcmd = "DUMPALL\n";
 	struct	sockaddr_un sa;
 
 	memset(&sa, '\0', sizeof(sa));
@@ -345,7 +209,7 @@ int sstate_connect(upstype *ups)
 	/* get a dump started so we have a fresh set of data */
 	ret = write(fd, dumpcmd, strlen(dumpcmd));
 
-	if (ret != strlen(dumpcmd)) {
+	if ((ret < 1) || (ret != (int) strlen(dumpcmd))) {
 		close(fd);
 		upslog(LOG_ERR, "Initial write to UPS [%s] failed", ups->name);
 		return -1;
@@ -377,12 +241,16 @@ void sstate_sock_read(upstype *ups)
 			if ((ret == -1) && (errno == EAGAIN))
 				return;
 
-			upslog(LOG_NOTICE, "Read from UPS [%s] failed", 
-				ups->name);
+			if (ret == 0)
+				upslogx(LOG_WARNING, "UPS [%s] disconnected - "
+					"check driver", ups->name);
+			else
+				upslog(LOG_WARNING, "Read from UPS [%s] failed",
+					ups->name);
 
-	                sstate_infofree(ups);
-        	        sstate_cmdfree(ups);
-                	pconf_finish(&ups->sock_ctx);
+			sstate_infofree(ups);
+			sstate_cmdfree(ups);
+			pconf_finish(&ups->sock_ctx);
 
 			close(ups->sock_fd);
 			ups->sock_fd = -1;
@@ -411,36 +279,11 @@ void sstate_sock_read(upstype *ups)
 	}
 }
 
-/* strictly a name-based transform - no netcmds numerics */
-static const char *oldvar_to_new_noconv(const char *old)
+const char *sstate_getinfo(const upstype *ups, const char *var)
 {
-	int	i;
-
-	for (i = 0; var_map[i].name != NULL; i++)
-		if (!strcasecmp(var_map[i].old, old))
-			return var_map[i].name;
-
-	return NULL;
-}
-
-const char *sstate_getinfo(const upstype *ups, const char *var, int tryold)
-{
-	const	char	*new;
-
 	/* requesting an old variable name? */
-	if (!strchr(var, '.')) {
-
-		if (!tryold) 
-			return NULL;
-
-		new = oldvar_to_new_noconv(var);
-
-		/* if it's been mapped, look up the new name */
-		if (new)
-			return state_getinfo(ups->inforoot, new);
-
-		/* otherwise fall through and try it directly */
-	}
+	if (!strchr(var, '.'))
+		return NULL;
 
 	return state_getinfo(ups->inforoot, var);
 }
@@ -465,28 +308,6 @@ const struct cmdlist_t *sstate_getcmdlist(const upstype *ups)
 	return ups->cmdlist;
 }
 
-void sstate_makeinfolist(const upstype *ups, char *buf, size_t bufsize)
-{
-	geninfolist(ups->inforoot, buf, bufsize, 0);
-}
-
-void sstate_makerwlist(const upstype *ups, char *buf, size_t bufsize)
-{
-	geninfolist(ups->inforoot, buf, bufsize, 1);
-}
-
-void sstate_makeinstcmdlist(const upstype *ups, char *buf, size_t bufsize)
-{
-	struct	cmdlist_t	*tmp;
-
-	tmp = ups->cmdlist;
-
-	while (tmp) {
-		append_oldcmdname(buf, bufsize, tmp->name);
-		tmp = tmp->next;
-	}
-}
-
 int sstate_dead(upstype *ups, int maxage)
 {
 	time_t	now;
@@ -550,12 +371,12 @@ int sstate_sendline(upstype *ups, const char *buf)
 
 	ret = write(ups->sock_fd, buf, strlen(buf));
 
-	if (ret != strlen(buf)) {
+	if ((ret < 1) || (ret != (int) strlen(buf))) {
 		upslog(LOG_NOTICE, "Send to UPS [%s] failed", ups->name);
 
-                sstate_infofree(ups);
-                sstate_cmdfree(ups);
-                pconf_finish(&ups->sock_ctx);
+		sstate_infofree(ups);
+		sstate_cmdfree(ups);
+		pconf_finish(&ups->sock_ctx);
 
 		close(ups->sock_fd);
 		ups->sock_fd = -1;
