@@ -64,7 +64,7 @@ static	struct	in_addr	listenaddr;
 
 	/* signal handlers */
 static	struct sigaction sa;
-static	sigset_t upsd_sigmask;
+static	sigset_t nut_upsd_sigmask;
 
 	/* pid file */
 static	char	pidfn[SMALLBUF];
@@ -179,7 +179,7 @@ static void declogins(const char *upsname)
 
 	if (ups->numlogins < 0)
 		upslogx(LOG_ERR, "Programming error: UPS [%s] has numlogins=%d",
-			ups, ups->numlogins);
+			ups->name, ups->numlogins);
 }
 
 /* disconnect a client connection and free all related memory */
@@ -685,8 +685,8 @@ static void set_exit_flag(int sig)
 /* basic signal setup to ignore SIGPIPE */
 static void setupsignals(void)
 {
-	sigemptyset(&upsd_sigmask);
-	sa.sa_mask = upsd_sigmask;
+	sigemptyset(&nut_upsd_sigmask);
+	sa.sa_mask = nut_upsd_sigmask;
 	sa.sa_flags = 0;
 
 	sa.sa_handler = SIG_IGN;
