@@ -529,12 +529,11 @@ static void user_parse_arg(int numargs, char **arg)
 
 	/* look for section headers - [username] */
 	if ((arg[0][0] == '[') && (arg[0][strlen(arg[0])-1] == ']')) {
-                
 		arg[0][strlen(arg[0])-1] = '\0';
 		user_add(&arg[0][1]);
 
-                return;
-        }
+		return;
+	}
 
 	if (numargs < 2)
 		return;
@@ -562,9 +561,9 @@ static void user_parse_arg(int numargs, char **arg)
 }
 
 /* called for fatal errors in parseconf like malloc failures */
-void upsd_user_err(const char *errmsg)
+static void upsd_user_err(const char *errmsg)
 {
-        upslogx(LOG_ERR, "Fatal error in parseconf(upsd.users): %s", errmsg);
+	upslogx(LOG_ERR, "Fatal error in parseconf(upsd.users): %s", errmsg);
 }
 
 void user_load(void)
